@@ -21,7 +21,6 @@ from gi.repository import Gtk, Gio, GLib, Gdk, Notify, TotemPlParser
 
 from pickle import dump
 from gettext import gettext as _
-from threading import Thread
 
 
 try:
@@ -30,15 +29,16 @@ except Exception as e:
     print(e)
     print(_("    - Scrobbler disabled\n"
             "    - Auto cover download disabled\n"
-            "    - Artist informations disabled"))
+            "    - Artist information disabled"))
     print("$ sudo pip3 install pylast")
     LastFM = None
 
-from lollypop.utils import is_gnome, is_unity, get_network_available
-from lollypop.define import Type, DataPath
+from lollypop.utils import is_gnome, is_unity
+from lollypop.define import Type, LOLLYPOP_DATA_PATH
 from lollypop.window import Window
 from lollypop.database import Database
 from lollypop.player import Player
+from lollypop.inhibitor import Inhibitor
 from lollypop.art import Art
 from lollypop.sqlcursor import SqlCursor
 from lollypop.settings import Settings, SettingsDialog
@@ -46,10 +46,11 @@ from lollypop.database_albums import AlbumsDatabase
 from lollypop.database_artists import ArtistsDatabase
 from lollypop.database_genres import GenresDatabase
 from lollypop.database_tracks import TracksDatabase
+from lollypop.notification import NotificationManager
 from lollypop.playlists import Playlists
 from lollypop.objects import Album, Track
+from lollypop.helper_task import TaskHelper
 from lollypop.collectionscanner import CollectionScanner
-from lollypop.lio import Lio
 
 
 class Application(Gtk.Application):
@@ -90,7 +91,9 @@ class Application(Gtk.Application):
         self.window = None
         self.notify = None
         self.lastfm = None
+        self.librefm = None
         self.debug = False
+        self.__fs = None
         self.__externals_count = 0
         self.__init_proxy()
         GLib.set_application_name("Lollypop")
@@ -100,7 +103,7 @@ class Application(Gtk.Application):
         self.add_main_option("debug", b"d", GLib.OptionFlags.NONE,
                              GLib.OptionArg.NONE, "Debug lollypop", None)
         self.add_main_option("set-rating", b"r", GLib.OptionFlags.NONE,
-                             GLib.OptionArg.INT, "Rate the current track",
+                             GLib.OptionArg.STRING, "Rate the current track",
                              None)
         self.add_main_option("play-pause", b"t", GLib.OptionFlags.NONE,
                              GLib.OptionArg.NONE, "Toggle playback",
@@ -145,13 +148,13 @@ class Application(Gtk.Application):
                                          None)
         except Exception as e:
             print("Application::init():", e)
-        self.__is_fs = False
+
         if Gtk.get_minor_version() > 18:
-            cssProviderFile = Lio.File.new_for_uri(
-                "resource:///org/gnome/Lollypop/application.css")
+            cssProviderFile = Gio.File.new_for_uri(
+                 "resource:///org/gnome/Lollypop/application.css")
         else:
-            cssProviderFile = Lio.File.new_for_uri(
-                "resource:///org/gnome/Lollypop/application-legacy.css")
+            cssProviderFile = Gio.File.new_for_uri(
+                 "resource:///org/gnome/Lollypop/application-legacy.css")
         cssProvider = Gtk.CssProvider()
         cssProvider.load_from_file(cssProviderFile)
         screen = Gdk.Screen.get_default()
@@ -168,24 +171,19 @@ class Application(Gtk.Application):
         self.genres = GenresDatabase()
         self.tracks = TracksDatabase()
         self.player = Player()
+        self.inhibitor = Inhibitor()
         self.scanner = CollectionScanner()
         self.art = Art()
+        self.notify = NotificationManager()
         self.art.update_art_size()
         if self.settings.get_value("artist-artwork"):
             GLib.timeout_add(5000, self.art.cache_artists_info)
         if LastFM is not None:
-            self.lastfm = LastFM()
+            self.lastfm = LastFM("lastfm")
+            self.librefm = LastFM("librefm")
         if not self.settings.get_value("disable-mpris"):
-            # Ubuntu > 16.04
-            if Gtk.get_minor_version() > 18:
-                from lollypop.mpris import MPRIS
-            # Ubuntu <= 16.04, Debian Jessie, ElementaryOS
-            else:
-                from lollypop.mpris_legacy import MPRIS
+            from lollypop.mpris import MPRIS
             MPRIS(self)
-        if not self.settings.get_value("disable-notifications"):
-            from lollypop.notification import NotificationManager
-            self.notify = NotificationManager()
 
         settings = Gtk.Settings.get_default()
         self.__gtk_dark = settings.get_property(
@@ -224,16 +222,6 @@ class Application(Gtk.Application):
             # We add to mainloop as we want to run
             # after player::restore_state() signals
             GLib.idle_add(self.window.toolbar.set_mark)
-            self.charts = None
-            if self.settings.get_value("show-charts"):
-                if GLib.find_program_in_path("youtube-dl") is not None:
-                    from lollypop.charts import Charts
-                    self.charts = Charts()
-                    if get_network_available():
-                        self.charts.start()
-                else:
-                    self.settings.set_value("network-search",
-                                            GLib.Variant("b", False))
             self.__preload_portal()
 
     def quit(self, vacuum=False):
@@ -253,7 +241,7 @@ class Application(Gtk.Application):
         """
             Return True if application is fullscreen
         """
-        return self.__is_fs
+        return self.__fs is not None
 
     def set_mini(self, action, param):
         """
@@ -279,7 +267,7 @@ class Application(Gtk.Application):
         """
             Save window position and view
         """
-        if self.__is_fs:
+        if self.is_fullscreen():
             return
         if self.settings.get_value("save-state"):
             self.window.save_view_state()
@@ -296,17 +284,17 @@ class Application(Gtk.Application):
                 # Save albums context
                 try:
                     dump(self.player.context.genre_ids,
-                         open(DataPath + "/genre_ids.bin", "wb"))
+                         open(LOLLYPOP_DATA_PATH + "/genre_ids.bin", "wb"))
                     dump(self.player.context.artist_ids,
-                         open(DataPath + "/artist_ids.bin", "wb"))
+                         open(LOLLYPOP_DATA_PATH + "/artist_ids.bin", "wb"))
                     self.player.shuffle_albums(False)
                     dump(self.player.get_albums(),
-                         open(DataPath + "/albums.bin", "wb"))
+                         open(LOLLYPOP_DATA_PATH + "/albums.bin", "wb"))
                 except Exception as e:
                     print("Application::__save_state()", e)
-            dump(track_id, open(DataPath + "/track_id.bin", "wb"))
+            dump(track_id, open(LOLLYPOP_DATA_PATH + "/track_id.bin", "wb"))
             dump([self.player.is_playing, self.player.is_party],
-                 open(DataPath + "/player.bin", "wb"))
+                 open(LOLLYPOP_DATA_PATH + "/player.bin", "wb"))
             # Save current playlist
             if self.player.current_track.id == Type.RADIOS:
                 playlist_ids = [Type.RADIOS]
@@ -315,16 +303,14 @@ class Application(Gtk.Application):
             else:
                 playlist_ids = self.player.get_user_playlist_ids()
             dump(playlist_ids,
-                 open(DataPath + "/playlist_ids.bin", "wb"))
+                 open(LOLLYPOP_DATA_PATH + "/playlist_ids.bin", "wb"))
         if self.player.current_track.id is not None:
             position = self.player.position
         else:
             position = 0
-        dump(position, open(DataPath + "/position.bin", "wb"))
+        dump(position, open(LOLLYPOP_DATA_PATH + "/position.bin", "wb"))
         self.player.stop_all()
         self.window.stop_all()
-        if self.charts is not None:
-            self.charts.stop()
 
     def __vacuum(self):
         """
@@ -334,7 +320,6 @@ class Application(Gtk.Application):
             self.scanner.stop()
             GLib.idle_add(self.__vacuum)
             return
-        self.db.del_tracks(self.tracks.get_non_persistent())
         try:
             from lollypop.radios import Radios
             with SqlCursor(self.db) as sql:
@@ -406,10 +391,14 @@ class Application(Gtk.Application):
         if options.contains("debug"):
             self.debug = True
         if options.contains("set-rating"):
-            value = options.lookup_value("set-rating").get_int32()
-            if value > 0 and value < 6 and\
-                    self.player.current_track.id is not None:
-                self.player.current_track.set_rate(value)
+            value = options.lookup_value("set-rating").get_string()
+            try:
+                value = min(max(0, int(value)), 5)
+                if self.player.current_track.id is not None:
+                    self.player.current_track.set_rate(value)
+            except Exception as e:
+                print(e)
+                pass
         elif options.contains("play-pause"):
             self.player.play_pause()
         elif options.contains("play-ids"):
@@ -498,9 +487,8 @@ class Application(Gtk.Application):
             @param param as GLib.Variant
         """
         if self.window:
-            t = Thread(target=self.art.clean_all_cache)
-            t.daemon = True
-            t.start()
+            helper = TaskHelper()
+            helper.run(self.art.clean_all_cache)
             self.window.update_db()
 
     def __set_network(self, action, param):
@@ -511,32 +499,27 @@ class Application(Gtk.Application):
         """
         action.set_state(param)
         self.settings.set_value("network-access", param)
-        if self.charts is not None:
-            if param.get_boolean():
-                self.charts.start()
-            else:
-                self.charts.stop()
-        self.window.reload_view()
 
     def __fullscreen(self, action=None, param=None):
         """
-            Show a fullscreen window with cover and artist informations
+            Show a fullscreen window with cover and artist information
             @param action as Gio.SimpleAction
             @param param as GLib.Variant
         """
-        if self.window and not self.__is_fs:
+        if self.window and not self.is_fullscreen():
             from lollypop.fullscreen import FullScreen
-            fs = FullScreen(self, self.window)
-            fs.connect("destroy", self.__on_fs_destroyed)
-            self.__is_fs = True
-            fs.show()
+            self.__fs = FullScreen(self, self.window)
+            self.__fs.connect("destroy", self.__on_fs_destroyed)
+            self.__fs.show()
+        elif self.window and self.is_fullscreen():
+            self.__fs.destroy()
 
     def __on_fs_destroyed(self, widget):
         """
             Mark fullscreen as False
             @param widget as Fullscreen
         """
-        self.__is_fs = False
+        self.__fs = None
         if not self.window.is_visible():
             self.quit(True)
 
