@@ -12,7 +12,6 @@
 
 from gi.repository import GLib, Gdk, GdkPixbuf, Gio, Gst
 
-from threading import Thread
 import re
 
 from lollypop.art_base import BaseArt
@@ -20,8 +19,8 @@ from lollypop.tagreader import TagReader
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
 from lollypop.utils import escape, is_readonly
-from lollypop.lio import Lio
 from lollypop.helper_dbus import DBusHelper
+from lollypop.helper_task import TaskHelper
 
 
 class AlbumArt(BaseArt, TagReader):
@@ -33,7 +32,7 @@ class AlbumArt(BaseArt, TagReader):
 
     def __init__(self):
         """
-            Init radio art
+            Init album art
         """
         BaseArt.__init__(self)
         TagReader.__init__(self)
@@ -53,7 +52,7 @@ class AlbumArt(BaseArt, TagReader):
             cache_path_jpg = "%s/%s_%s.jpg" % (self._CACHE_PATH,
                                                filename,
                                                size)
-            f = Lio.File.new_for_path(cache_path_jpg)
+            f = Gio.File.new_for_path(cache_path_jpg)
             if f.query_exists():
                 return cache_path_jpg
             else:
@@ -90,7 +89,7 @@ class AlbumArt(BaseArt, TagReader):
                 album.uri + "/" + filename
             ]
             for uri in uris:
-                f = Lio.File.new_for_uri(uri)
+                f = Gio.File.new_for_uri(uri)
                 if f.query_exists():
                     return uri
         except:
@@ -106,7 +105,7 @@ class AlbumArt(BaseArt, TagReader):
         # Folders with many albums, get_album_artwork_uri()
         if Lp().albums.get_uri_count(album.uri) > 1:
             return None
-        f = Lio.File.new_for_uri(album.uri)
+        f = Gio.File.new_for_uri(album.uri)
         infos = f.enumerate_children("standard::name",
                                      Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
                                      None)
@@ -124,20 +123,22 @@ class AlbumArt(BaseArt, TagReader):
             @param album as Album
             @return [paths]
         """
-        if album.is_web:
-            return []
-
-        f = Lio.File.new_for_uri(album.uri)
-        infos = f.enumerate_children("standard::name",
+        try:
+            f = Gio.File.new_for_uri(album.uri)
+            infos = f.enumerate_children(
+                                     "standard::name",
                                      Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
                                      None)
-        all_uris = []
-        for info in infos:
-            f = infos.get_child(info)
-            all_uris.append(f.get_uri())
-        uris = []
-        for uri in filter(lambda p: p.lower().endswith(self._MIMES), all_uris):
-            uris.append(uri)
+            all_uris = []
+            for info in infos:
+                f = infos.get_child(info)
+                all_uris.append(f.get_uri())
+            uris = []
+            for uri in filter(lambda p: p.lower().endswith(self._MIMES),
+                              all_uris):
+                uris.append(uri)
+        except Exception as e:
+            print("AlbumArt::get_album_artworks()", e)
         return uris
 
     def get_album_artwork(self, album, size, scale):
@@ -155,7 +156,7 @@ class AlbumArt(BaseArt, TagReader):
 
         try:
             # Look in cache
-            f = Lio.File.new_for_path(cache_path_jpg)
+            f = Gio.File.new_for_path(cache_path_jpg)
             if f.query_exists():
                 pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(cache_path_jpg,
                                                                 size,
@@ -166,11 +167,12 @@ class AlbumArt(BaseArt, TagReader):
                     uri = self.get_album_artwork_uri(album)
                     data = None
                     if uri is not None:
-                        f = Lio.File.new_for_uri(uri)
+                        f = Gio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
                         ratio = self._respect_ratio(uri)
-                        stream = Gio.MemoryInputStream.new_from_data(data,
-                                                                     None)
+                        bytes = GLib.Bytes(data)
+                        stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+                        bytes.unref()
                         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                                                                        stream,
                                                                        size,
@@ -191,11 +193,12 @@ class AlbumArt(BaseArt, TagReader):
                     uri = self.get_first_album_artwork(album)
                     # Look in album folder
                     if uri is not None:
-                        f = Lio.File.new_for_uri(uri)
+                        f = Gio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
                         ratio = self._respect_ratio(uri)
-                        stream = Gio.MemoryInputStream.new_from_data(data,
-                                                                     None)
+                        bytes = GLib.Bytes(data)
+                        stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+                        bytes.unref()
                         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                                                                        stream,
                                                                        size,
@@ -214,7 +217,6 @@ class AlbumArt(BaseArt, TagReader):
                                  [str(Lp().settings.get_value(
                                                 "cover-quality").get_int32())])
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
-            del pixbuf
             return surface
 
         except Exception as e:
@@ -234,7 +236,6 @@ class AlbumArt(BaseArt, TagReader):
         pixbuf = self.pixbuf_from_tags(uri, size)
         if pixbuf is not None:
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
-            del pixbuf
             return surface
         else:
             return self.get_default_icon("folder-music-symbolic", size, scale)
@@ -248,15 +249,12 @@ class AlbumArt(BaseArt, TagReader):
         try:
             album = Album(album_id)
             arturi = None
-            save_to_tags = Lp().settings.get_value("save-to-tags") and\
-                not album.is_web
+            save_to_tags = Lp().settings.get_value("save-to-tags")
             uri_count = Lp().albums.get_uri_count(album.uri)
             filename = self.get_album_cache_name(album) + ".jpg"
             if save_to_tags:
-                t = Thread(target=self.__save_artwork_tags,
-                           args=(data, album))
-                t.daemon = True
-                t.start()
+                helper = TaskHelper()
+                helper.run(self.__save_artwork_tags, data, album)
 
             store_path = self._STORE_PATH + "/" + filename
             if album.uri == "" or is_readonly(album.uri):
@@ -265,14 +263,17 @@ class AlbumArt(BaseArt, TagReader):
             elif uri_count > 1:
                 arturi = album.uri + "/" + filename
                 favorite_uri = album.uri + "/" + self.__favorite
-                favorite = Lio.File.new_for_uri(favorite_uri)
+                favorite = Gio.File.new_for_uri(favorite_uri)
                 if favorite.query_exists():
                     favorite.trash()
             else:
                 arturi = album.uri + "/" + self.__favorite
             # Save cover to uri
-            if not save_to_tags:
-                stream = Gio.MemoryInputStream.new_from_data(data, None)
+            dst = Gio.File.new_for_uri(arturi)
+            if not save_to_tags or dst.query_exists():
+                bytes = GLib.Bytes(data)
+                stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+                bytes.unref()
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                                                                stream,
                                                                ArtSize.MONSTER,
@@ -283,16 +284,11 @@ class AlbumArt(BaseArt, TagReader):
                 pixbuf.savev(store_path, "jpeg", ["quality"],
                              [str(Lp().settings.get_value(
                                                 "cover-quality").get_int32())])
-                dst = Lio.File.new_for_uri(arturi)
-                src = Lio.File.new_for_path(store_path)
+                dst = Gio.File.new_for_uri(arturi)
+                src = Gio.File.new_for_path(store_path)
                 src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
-                del pixbuf
                 self.clean_album_cache(album)
                 GLib.idle_add(self.album_artwork_update, album.id)
-            else:
-                dst = Lio.File.new_for_uri(arturi)
-                if dst.query_exists():
-                    dst.trash()
         except Exception as e:
             print("Art::save_album_artwork(): %s" % e)
 
@@ -309,7 +305,7 @@ class AlbumArt(BaseArt, TagReader):
             @param album as Album
         """
         for uri in self.get_album_artworks(album):
-            f = Lio.File.new_for_uri(uri)
+            f = Gio.File.new_for_uri(uri)
             try:
                 f.trash()
             except:
@@ -325,7 +321,7 @@ class AlbumArt(BaseArt, TagReader):
         """
         cache_name = self.get_album_cache_name(album)
         try:
-            d = Lio.File.new_for_path(self._CACHE_PATH)
+            d = Gio.File.new_for_path(self._CACHE_PATH)
             infos = d.enumerate_children(
                 "standard::name",
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -360,8 +356,9 @@ class AlbumArt(BaseArt, TagReader):
             if exist:
                 (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
             if exist:
-                stream = Gio.MemoryInputStream.new_from_data(mapflags.data,
-                                                             None)
+                bytes = GLib.Bytes(mapflags.data)
+                stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+                bytes.unref()
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
                                                                    size,
                                                                    size,
@@ -390,9 +387,10 @@ class AlbumArt(BaseArt, TagReader):
             @param data as bytes
             @param album as Album
         """
-        if album.is_web:
-            return
-        stream = Gio.MemoryInputStream.new_from_data(data, None)
+        # https://bugzilla.gnome.org/show_bug.cgi?id=747431
+        bytes = GLib.Bytes(data)
+        stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+        bytes.unref()
         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
                                                            ArtSize.MONSTER,
                                                            ArtSize.MONSTER,
@@ -402,8 +400,7 @@ class AlbumArt(BaseArt, TagReader):
         pixbuf.savev("%s/lollypop_cover_tags.jpg" % self._CACHE_PATH,
                      "jpeg", ["quality"], [str(Lp().settings.get_value(
                                            "cover-quality").get_int32())])
-        del pixbuf
-        f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
+        f = Gio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
                                   self._CACHE_PATH)
         if f.query_exists():
             dbus_helper = DBusHelper()
@@ -418,7 +415,7 @@ class AlbumArt(BaseArt, TagReader):
             @param album_id as int
         """
         try:
-            can_set_cover = source.call_finish(result)
+            can_set_cover = source.call_finish(result)[0]
         except:
             can_set_cover = False
         if can_set_cover:
