@@ -15,24 +15,21 @@ from gi.repository import GLib, Gdk, GdkPixbuf, Gio
 import re
 
 from lollypop.art_base import BaseArt
-from lollypop.lio import Lio
+from lollypop.helper_task import TaskHelper
 
 
 class RadioArt(BaseArt):
     """
         Manage radio artwork
     """
-    if GLib.getenv("XDG_DATA_HOME") is None:
-        _RADIOS_PATH = GLib.get_home_dir() + "/.local/share/lollypop/radios"
-    else:
-        _RADIOS_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop/radios"
+    _RADIOS_PATH = GLib.get_user_data_dir() + "/lollypop/radios"
 
     def __init__(self):
         """
             Init radio art
         """
         BaseArt.__init__(self)
-        d = Lio.File.new_for_path(self._RADIOS_PATH)
+        d = Gio.File.new_for_path(self._RADIOS_PATH)
         if not d.query_exists():
             try:
                 d.make_directory_with_parents()
@@ -51,7 +48,7 @@ class RadioArt(BaseArt):
             cache_path_png = "%s/%s_%s.png" % (self._CACHE_PATH,
                                                filename,
                                                size)
-            f = Lio.File.new_for_path(cache_path_png)
+            f = Gio.File.new_for_path(cache_path_png)
             if f.query_exists():
                 return cache_path_png
             else:
@@ -81,7 +78,7 @@ class RadioArt(BaseArt):
 
         try:
             # Look in cache
-            f = Lio.File.new_for_path(cache_path_png)
+            f = Gio.File.new_for_path(cache_path_png)
             if f.query_exists():
                 pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(cache_path_png,
                                                                 size,
@@ -99,7 +96,6 @@ class RadioArt(BaseArt):
                                              scale)
             pixbuf.savev(cache_path_png, "png", [None], [None])
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
-            del pixbuf
             return surface
 
         except Exception as e:
@@ -111,17 +107,17 @@ class RadioArt(BaseArt):
     def copy_uri_to_cache(self, uri, name, size):
         """
             Copy uri to cache at size
-            @param uri as string
-            @param name as string
+            @param uri as str
+            @param name as str
             @param size as int
             @thread safe
         """
-        filename = self.__get_radio_cache_name(name)
-        cache_path_png = "%s/%s_%s.png" % (self._CACHE_PATH, filename, size)
-        s = Lio.File.new_for_uri(uri)
-        d = Lio.File.new_for_path(cache_path_png)
-        s.copy(d, Gio.FileCopyFlags.OVERWRITE, None, None)
-        GLib.idle_add(self.emit, "radio-artwork-changed", name)
+        helper = TaskHelper()
+        helper.load_uri_content(uri,
+                                None,
+                                self.__on_uri_content,
+                                name,
+                                size)
 
     def rename_radio(self, old_name, new_name):
         """
@@ -132,8 +128,8 @@ class RadioArt(BaseArt):
         old = "%s/%s.png" % (self._RADIOS_PATH, old_name)
         new = "%s/%s.png" % (self._RADIOS_PATH, new_name)
         try:
-            src = Lio.File.new_for_path(old)
-            dst = Lio.File.new_for_path(new)
+            src = Gio.File.new_for_path(old)
+            dst = Gio.File.new_for_path(new)
             src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
         except Exception as e:
             print("RadioArt::rename_radio(): %s" % e)
@@ -165,7 +161,7 @@ class RadioArt(BaseArt):
         """
         cache_name = self.__get_radio_cache_name(name)
         try:
-            f = Lio.File.new_for_path(self._CACHE_PATH)
+            f = Gio.File.new_for_path(self._CACHE_PATH)
             infos = f.enumerate_children(
                 "standard::name",
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -189,7 +185,7 @@ class RadioArt(BaseArt):
         """
         try:
             name = name.replace("/", "-")
-            f = Lio.File.new_for_path(self._RADIOS_PATH + "/" + name + ".png")
+            f = Gio.File.new_for_path(self._RADIOS_PATH + "/" + name + ".png")
             if f.query_exists():
                 return self._RADIOS_PATH + "/" + name + ".png"
             return None
@@ -203,3 +199,25 @@ class RadioArt(BaseArt):
             @param sql as sqlite cursor
         """
         return "@@"+name.replace("/", "-")+"@@radio@@"
+
+    def __on_uri_content(self, uri, status, content, name, size):
+        """
+            Save image
+            @param uri as str
+            @param status as bool
+            @param content as bytes  # The image
+            @param name as str
+            @param size as int
+        """
+        if status:
+            filename = self.__get_radio_cache_name(name)
+            cache_path_png = "%s/%s_%s.png" % (self._CACHE_PATH,
+                                               filename,
+                                               size)
+            bytes = GLib.Bytes(content)
+            stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+            pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
+            bytes.unref()
+            stream.close()
+            pixbuf.savev(cache_path_png, "png", [None], [None])
+            self.emit("radio-artwork-changed", name)
