@@ -12,25 +12,18 @@
 
 from gi.repository import Gio, GLib, GdkPixbuf
 
-from os import mkdir, path, rename
+from os import mkdir, path  # FIXME Use Gio
 
 from lollypop.utils import escape
 from lollypop.define import ArtSize, Lp
-from lollypop.lio import Lio
 
 
 class InfoCache:
     """
         Generic class to cache text and images
     """
-    if GLib.getenv("XDG_DATA_HOME") is None:
-        _INFO_PATH = GLib.get_home_dir() + "/.local/share/lollypop/info"
-    else:
-        _INFO_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop/info"
-    if GLib.getenv("XDG_CACHE_HOME") is None:
-        _CACHE_PATH = GLib.get_home_dir() + "/.cache/lollypop_info"
-    else:
-        _CACHE_PATH = GLib.getenv("XDG_CACHE_HOME") + "/lollypop_info"
+    _INFO_PATH = GLib.get_user_data_dir() + "/lollypop/info"
+    _CACHE_PATH = GLib.get_user_cache_dir() + "/lollypop_info"
 
     WEBSERVICES = [("lastfm", "_get_lastfm_artist_info",
                     "_get_lastfm_album_artwork"),
@@ -68,18 +61,6 @@ class InfoCache:
                                          suffix)
             if path.exists(filepath):
                 exists = True
-            else:
-                # FIXME Remove this code, support for old lollypop versions
-                #
-                old_path = "%s/%s_%s_%s.jpg" % (InfoCache._CACHE_PATH,
-                                                escape(prefix),
-                                                suffix,
-                                                ArtSize.ARTIST)
-                if path.exists(old_path):
-                    rename(old_path, filepath)
-                    exists = True
-                #
-                ##########################################################
         return exists
 
     def get_artwork(prefix, suffix, size):
@@ -115,7 +96,6 @@ class InfoCache:
                     else:
                         extract = pixbuf
                     if extract is None:
-                        del pixbuf
                         extract = GdkPixbuf.Pixbuf.new(
                                                     GdkPixbuf.Colorspace.RGB,
                                                     True, 8,
@@ -144,11 +124,9 @@ class InfoCache:
                                              pixbuf.get_height(),
                                              extract,
                                              0, 0)
-                        del pixbuf
                     extract.savev(filepath_at_size, "jpeg",
                                   ["quality"], [str(Lp().settings.get_value(
                                                 "cover-quality").get_int32())])
-                    del extract
                 return filepath_at_size
         except Exception as e:
             print("InfoCache::get_artwork():", e)
@@ -167,13 +145,13 @@ class InfoCache:
         content = None
         data = None
         if path.exists(filepath+".txt"):
-            f = Lio.File.new_for_path(filepath+".txt")
+            f = Gio.File.new_for_path(filepath+".txt")
             (status, content, tag) = f.load_contents()
             if not status:
                 content = None
             image_path = filepath+".jpg"
             if path.exists(image_path):
-                f = Lio.File.new_for_path(image_path)
+                f = Gio.File.new_for_path(image_path)
                 (status, data, tag) = f.load_contents()
                 if not status:
                     data = None
@@ -191,29 +169,30 @@ class InfoCache:
                                  escape(prefix),
                                  suffix)
         if content is not None:
-            f = Lio.File.new_for_path(filepath+".txt")
+            f = Gio.File.new_for_path(filepath+".txt")
             fstream = f.replace(None, False,
                                 Gio.FileCreateFlags.REPLACE_DESTINATION, None)
             if fstream is not None:
                 fstream.write(content, None)
                 fstream.close()
         if data is None:
-            f = Lio.File.new_for_path(filepath+".jpg")
+            f = Gio.File.new_for_path(filepath+".jpg")
             fstream = f.replace(None, False,
                                 Gio.FileCreateFlags.REPLACE_DESTINATION, None)
             fstream.close()
         else:
-            stream = Gio.MemoryInputStream.new_from_data(data, None)
+            bytes = GLib.Bytes(data)
+            stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+            bytes.unref()
             pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
                                                                ArtSize.ARTIST,
                                                                -1,
                                                                True,
                                                                None)
             stream.close()
-            pixbuf.savev(filepath+".jpg",
+            pixbuf.savev(filepath + ".jpg",
                          "jpeg", ["quality"], [str(Lp().settings.get_value(
                                                "cover-quality").get_int32())])
-            del pixbuf
 
     def remove(prefix, suffix):
         """
@@ -224,7 +203,7 @@ class InfoCache:
         filepath = "%s/%s_%s.txt" % (InfoCache._INFO_PATH,
                                      escape(prefix),
                                      suffix)
-        f = Lio.File.new_for_path(filepath)
+        f = Gio.File.new_for_path(filepath)
         try:
             f.delete(None)
         except:
@@ -232,7 +211,7 @@ class InfoCache:
         filepath = "%s/%s_%s.jpg" % (InfoCache._INFO_PATH,
                                      escape(prefix),
                                      suffix)
-        f = Lio.File.new_for_path(filepath)
+        f = Gio.File.new_for_path(filepath)
         try:
             f.delete(None)
         except:
@@ -250,7 +229,7 @@ class InfoCache:
                                             escape(prefix),
                                             suffix,
                                             ArtSize.ARTIST_SMALL*scale*i)
-            f = Lio.File.new_for_path(filepath)
+            f = Gio.File.new_for_path(filepath)
             try:
                 f.delete(None)
             except:
