@@ -16,7 +16,6 @@ import itertools
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import Lp, Type, OrderBy
 from lollypop.utils import remove_static_genres, noaccents
-from lollypop.utils import get_network_available
 
 
 class AlbumsDatabase:
@@ -31,7 +30,7 @@ class AlbumsDatabase:
         self.__max_count = 1
         self._cached_randoms = []
 
-    def add(self, name, artist_ids, uri, loved, popularity, rate):
+    def add(self, name, artist_ids, uri, loved, popularity, rate, mtime):
         """
             Add a new album to database
             @param Album name as string
@@ -40,16 +39,17 @@ class AlbumsDatabase:
             @param loved as bool
             @param popularity as int
             @param rate as int
+            @param mtime as int
             @return inserted rowid as int
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("INSERT INTO albums\
                                   (name, no_album_artist,\
-                                  uri, loved, popularity, rate, synced)\
-                                  VALUES (?, ?, ?, ?, ?, ?, ?)",
+                                  uri, loved, popularity, rate, mtime, synced)\
+                                  VALUES (?, ?, ?, ?, ?, ?, ?, ?)",
                                  (name, artist_ids == [],
-                                  uri, loved, popularity, rate, 0))
+                                  uri, loved, popularity, rate, mtime, 0))
             for artist_id in artist_ids:
                 sql.execute("INSERT INTO album_artists\
                              (album_id, artist_id)\
@@ -70,42 +70,20 @@ class AlbumsDatabase:
                             "album_artists (album_id, artist_id)"
                             "VALUES (?, ?)", (album_id, artist_id))
 
-    def add_genre(self, album_id, genre_id, mtime):
+    def add_genre(self, album_id, genre_id):
         """
             Add genre to album
             @param album id as int
             @param genre id as int
-            @param mtime as int
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
-            # Check if already exists:
-            result = sql.execute("SELECT mtime FROM album_genres\
-                                  WHERE album_id=? AND genre_id=?",
-                                 (album_id, genre_id))
-            v = result.fetchone()
-            if v is not None:
-                sql.execute("UPDATE album_genres\
-                             SET mtime=?\
-                             WHERE album_id=? AND genre_id=?",
-                            (mtime, album_id, genre_id))
-            else:
-                genres = self.get_genre_ids(album_id)
-                if genre_id not in genres:
-                    sql.execute("INSERT INTO\
-                                 album_genres (album_id, genre_id, mtime)\
-                                 VALUES (?, ?, ?)",
-                                (album_id, genre_id, mtime))
-
-    def del_genres(self, album_id):
-        """
-            Delete all genres for album
-            @parma album id as int
-            @warning: commit needed
-        """
-        with SqlCursor(Lp().db) as sql:
-            sql.execute("DELETE FROM album_genres "
-                        "WHERE album_id=?", (album_id,))
+            genres = self.get_genre_ids(album_id)
+            if genre_id not in genres:
+                sql.execute("INSERT INTO\
+                             album_genres (album_id, genre_id)\
+                             VALUES (?, ?)",
+                            (album_id, genre_id))
 
     def set_artist_ids(self, album_id, artist_ids):
         """
@@ -250,17 +228,10 @@ class AlbumsDatabase:
             @param year as str
         """
         with SqlCursor(Lp().db) as sql:
-            filters = (Type.CHARTS, year)
+            filters = (year, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres AS AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND year=?\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
+                       FROM albums\
+                       WHERE year=?"
             result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
@@ -275,35 +246,7 @@ class AlbumsDatabase:
                                  rowid=?", (album_id,))
 
             v = result.fetchone()
-            if v is not None:
-                return v[0]
-            return Type.NONE
-
-    def get_mtime(self, album_id, genre_ids=[]):
-        """
-            Get modification time, if genre_ids empty, only local albums
-            @param album_id as int
-            @param genre_ids as [int]
-            @return modification time as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            if genre_ids:
-                filters = tuple([album_id] + genre_ids)
-                request = "SELECT mtime FROM album_genres\
-                           WHERE album_id=?"
-                for genre_id in genre_ids:
-                    request += " AND genre_id=?"
-            else:
-                filters = (album_id,)
-                request = "SELECT mtime FROM album_genres AS AG\
-                           WHERE AG.album_id=?\
-                           AND NOT EXISTS (\
-                                SELECT mtime FROM album_genres\
-                                WHERE album_id=AG.album_id\
-                                AND genre_id < 0)"
-            result = sql.execute(request, filters)
-            v = result.fetchone()
-            if v is not None:
+            if v:
                 return v[0]
             return 0
 
@@ -357,12 +300,11 @@ class AlbumsDatabase:
                 return v[0]
             return 5
 
-    def get_id(self, album_name, artist_ids, remote):
+    def get_id(self, album_name, artist_ids):
         """
             Get non compilation album id
             @param Album name as string,
             @param artist ids as [int]
-            @param remote as bool
             @return Album id as int
         """
         with SqlCursor(Lp().db) as sql:
@@ -376,18 +318,10 @@ class AlbumsDatabase:
                 for artist_id in artist_ids:
                     request += "OR artist_id=? "
                 request += ")"
-                if remote:
-                    request += " AND synced=%s" % Type.NONE
-                else:
-                    request += " AND synced!=%s" % Type.NONE
             else:
                 request = "SELECT rowid FROM albums\
                            WHERE name=?\
                            AND no_album_artist=1"
-                if remote:
-                    request += " AND synced=%s" % Type.NONE
-                else:
-                    request += " AND synced!=%s" % Type.NONE
             result = sql.execute(request, filters)
             v = result.fetchone()
             if v is not None:
@@ -530,19 +464,11 @@ class AlbumsDatabase:
             @return array of album ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            filters = (Type.CHARTS, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres as AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND rate>=4\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY popularity DESC LIMIT %s" % limit
-            result = sql.execute(request, filters)
+                       FROM albums\
+                       WHERE rate>=4\
+                       ORDER BY popularity DESC LIMIT ?"
+            result = sql.execute(request, (limit,))
             return list(itertools.chain(*result))
 
     def get_populars(self, limit=100):
@@ -552,19 +478,11 @@ class AlbumsDatabase:
             @return array of album ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            filters = (Type.CHARTS, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres as AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND popularity!=0\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY popularity DESC LIMIT %s" % limit
-            result = sql.execute(request, filters)
+                       FROM albums\
+                       WHERE popularity!=0\
+                       ORDER BY popularity DESC LIMIT ?"
+            result = sql.execute(request, (limit,))
             return list(itertools.chain(*result))
 
     def get_loves(self):
@@ -573,19 +491,11 @@ class AlbumsDatabase:
             @return array of album ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            filters = (Type.CHARTS, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres as AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND loved=1\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY popularity DESC"
-            result = sql.execute(request, filters)
+                       FROM albums\
+                       WHERE loved=1\
+                       ORDER BY popularity DESC"
+            result = sql.execute(request)
             return list(itertools.chain(*result))
 
     def get_recents(self):
@@ -594,18 +504,10 @@ class AlbumsDatabase:
             @return array of albums ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            filters = (Type.CHARTS, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres as AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY mtime DESC LIMIT 100"
-            result = sql.execute(request, filters)
+                       FROM albums\
+                       ORDER BY mtime DESC LIMIT 100"
+            result = sql.execute(request)
             return list(itertools.chain(*result))
 
     def get_randoms(self):
@@ -615,18 +517,9 @@ class AlbumsDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             albums = []
-            filters = (Type.CHARTS, )
             request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_genres as AG\
-                       WHERE ? NOT IN (\
-                            SELECT album_genres.genre_id\
-                            FROM album_genres\
-                            WHERE AG.album_id=album_genres.album_id)\
-                       AND AG.album_id=albums.rowid"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY random() LIMIT 100"
-            result = sql.execute(request, filters)
+                       FROM albums ORDER BY random() LIMIT 100"
+            result = sql.execute(request)
             albums = list(itertools.chain(*result))
             self._cached_randoms = list(albums)
             return albums
@@ -838,43 +731,6 @@ class AlbumsDatabase:
                 return v[0]
             return 0
 
-    def get_charts_ids(self, genre_ids=[]):
-        """
-            Get charts album ids
-            @param genre ids as [int]
-            @return albums ids as [int]
-        """
-        result = []
-        if genre_ids:
-            order = " ORDER BY mtime DESC,"
-        else:
-            order = " ORDER BY"
-        order += " artists.sortname\
-                   COLLATE NOCASE COLLATE LOCALIZED,\
-                   albums.year,\
-                   albums.name\
-                   COLLATE NOCASE COLLATE LOCALIZED"
-        with SqlCursor(Lp().db) as sql:
-            filters = tuple([Type.CHARTS] + genre_ids)
-            request = "SELECT DISTINCT albums.rowid FROM albums,\
-                       album_genres, artists, album_artists\
-                       WHERE EXISTS (\
-                            SELECT album_genres.album_id\
-                            FROM album_genres\
-                            WHERE albums.rowid = album_genres.album_id\
-                            AND album_genres.genre_id=?)\
-                       AND artists.rowid=album_artists.artist_id\
-                       AND albums.rowid=album_artists.album_id\
-                       AND album_genres.album_id=albums.rowid AND ("
-            for genre_id in genre_ids:
-                request += "album_genres.genre_id=? OR "
-            request += "1=0)"
-            if not get_network_available():
-                request += " AND albums.synced!=%s" % Type.NONE
-            request += order
-            result = sql.execute(request, filters)
-            return list(itertools.chain(*result))
-
     def get_ids(self, artist_ids=[], genre_ids=[]):
         """
             Get albums ids
@@ -906,89 +762,52 @@ class AlbumsDatabase:
             result = []
             # Get albums for all artists
             if not artist_ids and not genre_ids:
-                filters = (Type.CHARTS,)
                 request = "SELECT DISTINCT albums.rowid\
-                           FROM albums, artists,\
-                           album_artists, album_genres as AG\
-                           WHERE artists.rowid=album_artists.artist_id\
-                           AND ? NOT IN (\
-                                SELECT album_genres.genre_id\
-                                FROM album_genres\
-                                WHERE AG.album_id=album_genres.album_id)\
-                           AND AG.album_id=albums.rowid\
-                           AND albums.rowid=album_artists.album_id"
-                if not get_network_available():
-                    request += " AND albums.synced!=%s" % Type.NONE
+                           FROM albums, album_artists, artists\
+                           WHERE albums.rowid = album_artists.album_id AND\
+                           artists.rowid = album_artists.artist_id"
                 request += order
-                result = sql.execute(request, filters)
-            # Get albums for genre
+                result = sql.execute(request)
+            # Get albums for genres
             elif not artist_ids:
-                # Only show charts if wanted
-                if Type.CHARTS in genre_ids:
-                    filters = tuple(genre_ids)
-                else:
-                    filters = (Type.CHARTS,) + tuple(genre_ids)
+                filters = tuple(genre_ids)
                 request = "SELECT DISTINCT albums.rowid FROM albums,\
-                           album_genres as AG, artists, album_artists\
-                           WHERE artists.rowid=album_artists.artist_id\
-                           AND albums.rowid=album_artists.album_id "
-                if Type.CHARTS not in genre_ids:
-                    request += "AND ? NOT IN (\
-                                  SELECT album_genres.genre_id\
-                                  FROM album_genres\
-                                  WHERE AG.album_id=album_genres.album_id)"
-                request += " AND AG.album_id=albums.rowid AND ( "
+                           album_genres, album_artists, artists\
+                           WHERE albums.rowid = album_artists.album_id AND\
+                           artists.rowid = album_artists.artist_id AND\
+                           album_genres.album_id=albums.rowid AND ( "
                 for genre_id in genre_ids:
-                    request += "AG.genre_id=? OR "
+                    request += "album_genres.genre_id=? OR "
                 request += "1=0)"
-                if not get_network_available():
-                    request += " AND albums.synced!=%s" % Type.NONE
                 request += order
                 result = sql.execute(request, filters)
             # Get albums for artist
             elif not genre_ids:
-                filters = (Type.CHARTS,)
-                filters += tuple(artist_ids)
+                filters = tuple(artist_ids)
                 request = "SELECT DISTINCT albums.rowid\
-                           FROM albums, artists,\
-                           album_artists, album_genres as AG\
-                           WHERE artists.rowid=album_artists.artist_id\
-                           AND ? NOT IN (\
-                                SELECT album_genres.genre_id\
-                                FROM album_genres\
-                                WHERE AG.album_id=album_genres.album_id)\
-                           AND AG.album_id=albums.rowid\
-                           AND album_artists.album_id=albums.rowid AND ("
+                           FROM albums, album_artists, artists\
+                           WHERE album_artists.album_id=albums.rowid AND\
+                           artists.rowid = album_artists.artist_id AND ("
                 for artist_id in artist_ids:
-                    request += "album_artists.artist_id=? OR "
+                    request += "artists.rowid=? OR "
                 request += "1=0)"
-                if not get_network_available():
-                    request += " AND albums.synced!=%s" % Type.NONE
                 request += order
                 result = sql.execute(request, filters)
             # Get albums for artist id and genre id
             else:
-                filters = (Type.CHARTS,)
-                filters += tuple(artist_ids)
+                filters = tuple(artist_ids)
                 filters += tuple(genre_ids)
                 request = "SELECT DISTINCT albums.rowid\
-                           FROM albums, album_genres as AG,\
-                           artists, album_artists\
-                           WHERE AG.album_id=albums.rowid\
-                           AND artists.rowid=album_artists.artist_id\
-                           AND ? NOT IN (\
-                                SELECT album_genres.genre_id\
-                                FROM album_genres\
-                                WHERE AG.album_id=album_genres.album_id)\
-                           AND album_artists.album_id=albums.rowid AND ("
+                           FROM albums, album_genres, album_artists, artists\
+                           WHERE album_genres.album_id=albums.rowid AND\
+                           artists.rowid = album_artists.artist_id AND\
+                           album_artists.album_id=albums.rowid AND ("
                 for artist_id in artist_ids:
-                    request += "album_artists.artist_id=? OR "
+                    request += "artists.rowid=? OR "
                 request += "1=0) AND ("
                 for genre_id in genre_ids:
-                    request += "AG.genre_id=? OR "
+                    request += "album_genres.genre_id=? OR "
                 request += "1=0)"
-                if not get_network_available():
-                    request += " AND albums.synced!=%s" % Type.NONE
                 request += order
                 result = sql.execute(request, filters)
             return list(itertools.chain(*result))
@@ -1064,6 +883,20 @@ class AlbumsDatabase:
                                  (album_id,))
             return list(itertools.chain(*result))
 
+    def get_never_listened_to(self):
+        """
+            Return random albums never listened to
+            @return album ids as [int]
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT DISTINCT albums.rowid\
+                                  FROM albums, tracks\
+                                  WHERE tracks.ltime=0 AND\
+                                  albums.rowid=tracks.album_id\
+                                  AND albums.popularity < 10\
+                                  ORDER BY random() LIMIT 100")
+            return list(itertools.chain(*result))
+
     def has_loves(self):
         """
             True if db has loved albums
@@ -1074,9 +907,6 @@ class AlbumsDatabase:
             request = "SELECT albums.rowid\
                        FROM albums\
                        WHERE loved=1"
-            if not get_network_available():
-                request += " AND albums.synced!=?"
-                filters = (Type.NONE, )
             request += " LIMIT 1"
             result = sql.execute(request, filters)
             return list(itertools.chain(*result)) != []
@@ -1090,17 +920,12 @@ class AlbumsDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             if limit is None:
-                filters = ("%" + noaccents(string) + "%", Type.CHARTS)
+                filters = ("%" + noaccents(string) + "%",)
             else:
-                filters = ("%" + noaccents(string) + "%", Type.CHARTS, limit)
+                filters = ("%" + noaccents(string) + "%", limit)
             request = ("SELECT albums.rowid\
-                       FROM albums, album_genres AS AG\
-                       WHERE noaccents(name) LIKE ?\
-                       AND ? NOT IN (\
-                                SELECT album_genres.genre_id\
-                                FROM album_genres\
-                                WHERE AG.album_id=album_genres.album_id)\
-                       AND AG.album_id=albums.rowid")
+                       FROM albums\
+                       WHERE noaccents(name) LIKE ?")
             if limit is not None:
                 request += " LIMIT ?"
             result = sql.execute(request, filters)
@@ -1133,11 +958,7 @@ class AlbumsDatabase:
             @return int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT COUNT(1)\
-                                  FROM albums, album_genres\
-                                  WHERE album_genres.genre_id!=?\
-                                  AND album_genres.album_id=albums.rowid",
-                                 (Type.CHARTS,))
+            result = sql.execute("SELECT COUNT(1) FROM albums")
             v = result.fetchone()
             if v is not None:
                 return v[0]
