@@ -21,10 +21,7 @@ class History:
     """
         Playlists manager
     """
-    if GLib.getenv("XDG_DATA_HOME") is None:
-        __LOCAL_PATH = GLib.get_home_dir() + "/.local/share/lollypop"
-    else:
-        __LOCAL_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop"
+    __LOCAL_PATH = GLib.get_user_data_dir() + "/lollypop"
     __DB_PATH = "%s/history.db" % __LOCAL_PATH
     __LIMIT = 1000000  # Delete when limit is reached
     __DELETE = 100     # How many elements to delete
