@@ -18,6 +18,7 @@ from time import time
 from lollypop.sqlcursor import SqlCursor
 from lollypop.utils import translate_artist_name
 from lollypop.database_history import History
+from lollypop.radios import Radios
 from lollypop.define import Lp
 
 
@@ -55,6 +56,9 @@ class DatabaseUpgrade:
             18: self.__upgrade_18,
             19: self.__upgrade_19,
             20: self.__upgrade_20,
+            21: self.__upgrade_21,
+            22: self.__upgrade_22,
+            23: self.__upgrade_23,
                          }
 
     """
@@ -162,7 +166,7 @@ class DatabaseUpgrade:
         """
         with SqlCursor(Lp().db) as sql:
             sql.execute("ALTER TABLE tracks RENAME TO tmp_tracks")
-            sql.execute('''CREATE TABLE tracks (id INTEGER PRIMARY KEY,
+            sql.execute("""CREATE TABLE tracks (id INTEGER PRIMARY KEY,
                                               name TEXT NOT NULL,
                                               uri TEXT NOT NULL,
                                               duration INT,
@@ -175,15 +179,15 @@ class DatabaseUpgrade:
                                               ltime INT NOT NULL,
                                               mtime INT NOT NULL,
                                               persistent INT NOT NULL
-                                              DEFAULT 1)''')
+                                              DEFAULT 1)""")
 
-            sql.execute('''INSERT INTO tracks(id, name, uri, duration,
+            sql.execute("""INSERT INTO tracks(id, name, uri, duration,
                         tracknumber, discnumber, discname, album_id,
                         year, popularity, ltime, mtime, persistent) SELECT
                             id, name, filepath, duration,
                             tracknumber, discnumber, discname, album_id,
                             year, popularity, ltime, mtime, persistent FROM
-                          tmp_tracks''')
+                          tmp_tracks""")
             sql.execute("DROP TABLE tmp_tracks")
             result = sql.execute("SELECT rowid FROM tracks")
             for track_id in list(itertools.chain(*result)):
@@ -199,10 +203,10 @@ class DatabaseUpgrade:
             sql.commit()
         with SqlCursor(Lp().playlists) as sql:
             sql.execute("ALTER TABLE tracks RENAME TO tmp_tracks")
-            sql.execute('''CREATE TABLE tracks (playlist_id INT NOT NULL,
-                                                uri TEXT NOT NULL)''')
-            sql.execute('''INSERT INTO tracks(playlist_id, uri) SELECT
-                            playlist_id, filepath FROM tmp_tracks''')
+            sql.execute("""CREATE TABLE tracks (playlist_id INT NOT NULL,
+                                                uri TEXT NOT NULL)""")
+            sql.execute("""INSERT INTO tracks(playlist_id, uri) SELECT
+                            playlist_id, filepath FROM tmp_tracks""")
             sql.execute("DROP TABLE tmp_tracks")
             result = sql.execute("SELECT uri FROM tracks")
             for path in list(itertools.chain(*result)):
@@ -230,14 +234,14 @@ class DatabaseUpgrade:
         """
             Get ride of paths
         """
-        paths = Lp().settings.get_value('music-path')
+        paths = Lp().settings.get_value("music-path")
         uris = []
         for path in paths:
             uris.append(GLib.filename_to_uri(path))
-        Lp().settings.set_value('music-uris', GLib.Variant('as', uris))
+        Lp().settings.set_value("music-uris", GLib.Variant("as", uris))
         with SqlCursor(Lp().db) as sql:
             sql.execute("ALTER TABLE albums RENAME TO tmp_albums")
-            sql.execute('''CREATE TABLE albums (
+            sql.execute("""CREATE TABLE albums (
                                               id INTEGER PRIMARY KEY,
                                               name TEXT NOT NULL,
                                               no_album_artist BOOLEAN NOT NULL,
@@ -245,13 +249,13 @@ class DatabaseUpgrade:
                                               uri TEXT NOT NULL,
                                               popularity INT NOT NULL,
                                               synced INT NOT NULL,
-                                              mtime INT NOT NULL)''')
+                                              mtime INT NOT NULL)""")
 
-            sql.execute('''INSERT INTO albums(id, name, no_album_artist,
+            sql.execute("""INSERT INTO albums(id, name, no_album_artist,
                         year, uri, popularity, synced, mtime) SELECT
                             id, name, no_album_artist,
                             year, path, popularity, synced, mtime FROM
-                            tmp_albums''')
+                            tmp_albums""")
             sql.execute("DROP TABLE tmp_albums")
             result = sql.execute("SELECT rowid, uri FROM albums")
             for (rowid, uri) in result:
@@ -403,5 +407,117 @@ class DatabaseUpgrade:
                                    persistent FROM backup")
             sql.execute("DROP TABLE backup")
             sql.commit()
-        # Clean all charts
-        Lp().db.del_tracks(Lp().tracks.get_old_charts_track_ids(mtime*2))
+
+    def __upgrade_21(self):
+        """
+            Add rate to radios
+        """
+        with SqlCursor(Radios()) as sql:
+            sql.execute("ALTER TABLE radios ADD rate\
+                         INT NOT NULL DEFAULT -1")
+            sql.commit()
+
+    def __upgrade_22(self):
+        """
+            Remove Charts/Web entries
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rowid FROM tracks\
+                                  WHERE persistent=0 OR\
+                                  persistent=2 OR\
+                                  persistent=3")
+            track_ids = list(itertools.chain(*result))
+            Lp().db.del_tracks(track_ids)
+            # Remove persistent from tracks table
+            sql.execute("CREATE TEMPORARY TABLE backup(\
+                                          id INTEGER PRIMARY KEY,\
+                                          name TEXT NOT NULL,\
+                                          uri TEXT NOT NULL,\
+                                          duration INT,\
+                                          tracknumber INT,\
+                                          discnumber INT,\
+                                          discname TEXT,\
+                                          album_id INT NOT NULL,\
+                                          year INT,\
+                                          popularity INT NOT NULL,\
+                                          rate INT NOT NULL,\
+                                          ltime INT NOT NULL)")
+            sql.execute("INSERT INTO backup\
+                            SELECT id,\
+                                   name,\
+                                   uri,\
+                                   duration,\
+                                   tracknumber,\
+                                   discnumber,\
+                                   discname,\
+                                   album_id,\
+                                   year,\
+                                   popularity,\
+                                   rate,\
+                                   ltime FROM tracks")
+            sql.execute("DROP TABLE tracks")
+            sql.execute("CREATE TABLE tracks(\
+                                          id INTEGER PRIMARY KEY,\
+                                          name TEXT NOT NULL,\
+                                          uri TEXT NOT NULL,\
+                                          duration INT,\
+                                          tracknumber INT,\
+                                          discnumber INT,\
+                                          discname TEXT,\
+                                          album_id INT NOT NULL,\
+                                          year INT,\
+                                          popularity INT NOT NULL,\
+                                          rate INT NOT NULL,\
+                                          ltime INT NOT NULL)")
+            sql.execute("INSERT INTO tracks\
+                            SELECT id,\
+                                   name,\
+                                   uri,\
+                                   duration,\
+                                   tracknumber,\
+                                   discnumber,\
+                                   discname,\
+                                   album_id,\
+                                   year,\
+                                   popularity,\
+                                   rate,\
+                                   ltime FROM backup")
+            sql.execute("DROP TABLE backup")
+            sql.commit()
+
+    def __upgrade_23(self):
+        """
+            Restore back mtime in tracks
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("ALTER TABLE tracks ADD mtime INT")
+            sql.execute("ALTER TABLE albums ADD mtime INT")
+
+            sql.execute("UPDATE tracks SET mtime = (\
+                            SELECT mtime FROM track_genres\
+                            WHERE track_genres.track_id=tracks.rowid)")
+
+            sql.execute("UPDATE albums SET mtime = (\
+                            SELECT mtime FROM album_genres\
+                            WHERE album_genres.album_id=albums.rowid)")
+            sql.commit()
+            # Remove mtime from album_genres table
+            sql.execute("CREATE TABLE album_genres2 (\
+                                                album_id INT NOT NULL,\
+                                                genre_id INT NOT NULL)")
+            sql.execute("INSERT INTO album_genres2\
+                            SELECT album_id,\
+                                   genre_id FROM album_genres")
+            sql.execute("DROP TABLE album_genres")
+            sql.execute("ALTER TABLE album_genres2 RENAME TO album_genres")
+
+            # Remove mtime from track_genres table
+            sql.execute("CREATE TABLE track_genres2 (\
+                                                track_id INT NOT NULL,\
+                                                genre_id INT NOT NULL)")
+            sql.execute("INSERT INTO track_genres2\
+                            SELECT track_id,\
+                                   genre_id FROM track_genres")
+            sql.execute("DROP TABLE track_genres")
+            sql.execute("ALTER TABLE track_genres2 RENAME TO track_genres")
+            sql.commit()
