@@ -13,25 +13,9 @@
 # This is global object initialised at lollypop start
 # member init order is important!
 
-from gi.repository import Gio
+from gi.repository import Gio, GLib
 
-from os import path
-
-try:
-    from gi.repository import Secret
-
-    SecretSchema = {
-        "org.gnome.Lollypop.lastfm.login": Secret.SchemaAttributeType.STRING
-    }
-    SecretAttributes = {
-        "org.gnome.Lollypop.lastfm.login": "Last.fm login"
-    }
-except:
-    Secret = None
-    SecretSchema = None
-    SecretAttributes = None
-
-DataPath = path.expanduser("~") + "/.local/share/lollypop"
+LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
 
 Lp = Gio.Application.get_default
 
@@ -47,13 +31,6 @@ class NextContext:
     STOP = 2             # Stop after track/album/artist
 
 
-class DbPersistent:
-    NONE = 0
-    INTERNAL = 1
-    EXTERNAL = 2
-    CHARTS = 3
-
-
 class OpenLink:
     NONE = 0
     OPEN = 1
@@ -99,6 +76,13 @@ class Shuffle:
     ALBUMS = 2           # Shuffle by albums on genre
 
 
+class PowerManagement:
+    NONE = 0             # Use OS defaults
+    IDLE = 1             # Inhibit screensaver
+    SUSPEND = 2          # Inhibit suspend
+    BOTH = 3             # Inhibit screensaver and suspend
+
+
 class WindowSize:
     SMALL = 400
     MEDIUM = 500
@@ -123,13 +107,9 @@ class Type:
     RADIOS = -6
     EXTERNALS = -7
     SEARCH = -8
-    CHARTS = -9
-    SPOTIFY = -10
-    ITUNES = -11
-    LASTFM = -12
-    NOPARTY = -13
-    ALBUMS = -14
-    ALL = -15
+    NOPARTY = -9
+    ALBUMS = -10
+    ALL = -11
     LOVED = -997
     NEVER = -998
     DEVICES = -1000
