@@ -10,15 +10,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib
+from gi.repository import GLib, Soup
 
-from threading import Thread
 import json
+from base64 import b64encode
 
 from lollypop.cache import InfoCache
 from lollypop.define import Lp, GOOGLE_API_ID, Type
+from lollypop.define import SPOTIFY_CLIENT_ID, SPOTIFY_SECRET
 from lollypop.utils import debug, get_network_available
-from lollypop.lio import Lio
+from lollypop.helper_task import TaskHelper
 
 
 class Downloader:
@@ -49,9 +50,8 @@ class Downloader:
         if get_network_available():
             self.__albums_queue.append(album_id)
             if not self.__in_albums_download:
-                t = Thread(target=self.__cache_albums_art)
-                t.daemon = True
-                t.start()
+                helper = TaskHelper()
+                helper.run(self.__cache_albums_art)
 
     def cache_artists_info(self):
         """
@@ -60,44 +60,39 @@ class Downloader:
         if self.__cache_artists_running:
             return
         self.__cache_artists_running = True
-        t = Thread(target=self.__cache_artists_info)
-        t.daemon = True
-        t.start()
+        helper = TaskHelper()
+        helper.run(self.__cache_artists_info)
 
-    def get_google_arts(self, search):
+    def get_google_search_uri(self, search):
         """
-            Get arts on duck image corresponding to search
-            @param search words as string
+            Get google uri for search
+            @param search as str
+        """
+        key = Lp().settings.get_value("cs-api-key").get_string() or\
+            Lp().settings.get_default_value("cs-api-key").get_string()
+        uri = "https://www.googleapis.com/" +\
+              "customsearch/v1?key=%s&cx=%s" % (key, GOOGLE_API_ID) +\
+              "&q=%s&searchType=image" % GLib.uri_escape_string(search,
+                                                                "",
+                                                                False)
+        return uri
+
+    def get_google_artwork(self, content):
+        """
+            Get artwork from Google search content
+            @param content as bytes
             @return [urls as string]
         """
-        data = None
-        urls = []
-
-        if not get_network_available():
-            return []
-
-        cs_api_key = Lp().settings.get_value("cs-api-key").get_string()
-
+        uris = []
         try:
-            f = Lio.File.new_for_uri("https://www.googleapis.com/"
-                                     "customsearch/v1?key=%s&cx=%s"
-                                     "&q=%s&searchType=image" %
-                                     (cs_api_key,
-                                      GOOGLE_API_ID,
-                                      GLib.uri_escape_string(search,
-                                                             "",
-                                                             False)))
-
-            (status, data, tag) = f.load_contents()
-            if status:
-                decode = json.loads(data.decode("utf-8"))
-                if decode is None:
-                    return urls
-                for item in decode["items"]:
-                    urls.append(item["link"])
+            decode = json.loads(content.decode("utf-8"))
+            if decode is None:
+                return uris
+            for item in decode["items"]:
+                uris.append(item["link"])
         except Exception as e:
-            print(e)
-        return urls
+            print("Downloader::get_google_artwork():", e)
+        return uris or None
 
 #######################
 # PROTECTED           #
@@ -134,10 +129,10 @@ class Downloader:
         try:
             artist_formated = GLib.uri_escape_string(
                                 artist, None, True).replace(" ", "+")
-            s = Lio.File.new_for_uri("https://api.deezer.com/search/artist/?"
-                                     "q=%s&output=json&index=0&limit=1&" %
-                                     artist_formated)
-            (status, data, tag) = s.load_contents()
+            uri = "https://api.deezer.com/search/artist/?" +\
+                  "q=%s&output=json&index=0&limit=1&" % artist_formated
+            helper = TaskHelper()
+            (status, data) = helper.load_uri_content_sync(uri, None)
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 return (decode["data"][0]["picture_xl"], None)
@@ -155,9 +150,12 @@ class Downloader:
         try:
             artist_formated = GLib.uri_escape_string(
                                 artist, None, True).replace(" ", "+")
-            s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
-                                     "&type=artist" % artist_formated)
-            (status, data, tag) = s.load_contents()
+            uri = "https://api.spotify.com/v1/search?q=%s" % artist_formated +\
+                  "&type=artist"
+            token = "Bearer %s" % self.__get_spotify_token(None)
+            helper = TaskHelper()
+            helper.add_header("Authorization", token)
+            (status, data) = helper.load_uri_content_sync(uri, None)
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 for item in decode["artists"]["items"]:
@@ -179,20 +177,19 @@ class Downloader:
         image = None
         try:
             album_formated = GLib.uri_escape_string(album, None, True)
-            s = Lio.File.new_for_uri("https://api.deezer.com/search/album/?"
-                                     "q=%s&output=json" %
-                                     album_formated)
-            (status, data, tag) = s.load_contents()
+            uri = "https://api.deezer.com/search/album/?" +\
+                  "q=%s&output=json" % album_formated
+            helper = TaskHelper()
+            (status, data) = helper.load_uri_content_sync(uri, None)
             if status:
                 decode = json.loads(data.decode("utf-8"))
-                url = None
+                uri = None
                 for item in decode["data"]:
                     if item["artist"]["name"].lower() == artist.lower():
-                        url = item["cover_xl"]
+                        uri = item["cover_xl"]
                         break
-                if url is not None:
-                    s = Lio.File.new_for_uri(url)
-                    (status, image, tag) = s.load_contents()
+                if uri is not None:
+                    (status, image) = helper.load_uri_content_sync(uri, None)
         except Exception as e:
             print("Downloader::__get_deezer_album_artwork: %s" % e)
         return image
@@ -208,31 +205,34 @@ class Downloader:
         image = None
         artists_spotify_ids = []
         try:
+            token = self.__get_spotify_token(None)
             artist_formated = GLib.uri_escape_string(
                                 artist, None, True).replace(" ", "+")
-            s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
-                                     "&type=artist" % artist_formated)
-            (status, data, tag) = s.load_contents()
+            uri = "https://api.spotify.com/v1/search?q=%s" % artist_formated +\
+                  "&type=artist"
+            token = "Bearer %s" % token
+            helper = TaskHelper()
+            helper.add_header("Authorization", token)
+            (status, data) = helper.load_uri_content_sync(uri, None)
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 for item in decode["artists"]["items"]:
                     artists_spotify_ids.append(item["id"])
 
             for artist_spotify_id in artists_spotify_ids:
-                s = Lio.File.new_for_uri("https://api.spotify.com/v1/artists/"
-                                         "%s/albums" % artist_spotify_id)
-                (status, data, tag) = s.load_contents()
+                uri = "https://api.spotify.com/v1/artists/" +\
+                      "%s/albums" % artist_spotify_id
+                (status, data) = helper.load_uri_content_sync(uri, None)
                 if status:
                     decode = json.loads(data.decode("utf-8"))
-                    url = None
+                    uri = None
                     for item in decode["items"]:
                         if item["name"] == album:
-                            url = item["images"][0]["url"]
+                            uri = item["images"][0]["url"]
                             break
-
-                    if url is not None:
-                        s = Lio.File.new_for_uri(url)
-                        (status, image, tag) = s.load_contents()
+                    if uri is not None:
+                        (status, image) = helper.load_uri_content_sync(uri,
+                                                                       None)
                     break
         except Exception as e:
             print("Downloader::_get_album_art_spotify: %s [%s/%s]" %
@@ -251,17 +251,18 @@ class Downloader:
         try:
             album_formated = GLib.uri_escape_string(
                                 album, None, True).replace(" ", "+")
-            s = Lio.File.new_for_uri("https://itunes.apple.com/search"
-                                     "?entity=album&term=%s" % album_formated)
-            (status, data, tag) = s.load_contents()
+            uri = "https://itunes.apple.com/search" +\
+                  "?entity=album&term=%s" % album_formated
+            helper = TaskHelper()
+            (status, data) = helper.load_uri_content_sync(uri, None)
             if status:
                 decode = json.loads(data.decode("utf-8"))
                 for item in decode["results"]:
                     if item["artistName"].lower() == artist.lower():
-                        url = item["artworkUrl60"].replace("60x60",
+                        uri = item["artworkUrl60"].replace("60x60",
                                                            "512x512")
-                        s = Lio.File.new_for_uri(url)
-                        (status, image, tag) = s.load_contents()
+                        (status, image) = helper.load_uri_content_sync(uri,
+                                                                       None)
                         break
         except Exception as e:
             print("Downloader::_get_album_art_itunes: %s [%s/%s]" %
@@ -279,11 +280,11 @@ class Downloader:
         image = None
         if Lp().lastfm is not None:
             try:
+                helper = TaskHelper()
                 last_album = Lp().lastfm.get_album(artist, album)
-                url = last_album.get_cover_image(4)
-                if url is not None:
-                    s = Lio.File.new_for_uri(url)
-                    (status, image, tag) = s.load_contents()
+                uri = last_album.get_cover_image(4)
+                if uri is not None:
+                    (status, image) = helper.load_uri_content_sync(uri, None)
             except Exception as e:
                 print("Downloader::_get_album_art_lastfm: %s [%s/%s]" %
                       (e, artist, album))
@@ -292,6 +293,31 @@ class Downloader:
 #######################
 # PRIVATE             #
 #######################
+    def __get_spotify_token(self, cancellable):
+        """
+            Get a new auth token
+            @param cancellable as Gio.Cancellable
+            @return str
+        """
+        try:
+            token_uri = "https://accounts.spotify.com/api/token"
+            credentials = "%s:%s" % (SPOTIFY_CLIENT_ID, SPOTIFY_SECRET)
+            encoded = b64encode(credentials.encode("utf-8"))
+            credentials = encoded.decode("utf-8")
+            session = Soup.Session.new()
+            data = {"grant_type": "client_credentials"}
+            msg = Soup.form_request_new_from_hash("POST", token_uri, data)
+            msg.request_headers.append("Authorization",
+                                       "Basic %s" % credentials)
+            status = session.send_message(msg)
+            if status == 200:
+                body = msg.get_property("response-body")
+                data = body.flatten().get_data()
+                decode = json.loads(data.decode("utf-8"))
+                return decode["access_token"]
+        except:
+            return ""
+
     def __cache_artists_info(self):
         """
             Cache info for all artists
@@ -311,15 +337,16 @@ class Downloader:
                     continue
                 try:
                     method = getattr(self, helper)
-                    (url, content) = method(artist)
-                    if url is not None:
-                        s = Lio.File.new_for_uri(url)
-                        (status, data, tag) = s.load_contents()
+                    (uri, content) = method(artist)
+                    if uri is not None:
+                        (status, data) = TaskHelper().load_uri_content_sync(
+                                                                      uri,
+                                                                      None)
                         if status:
                             artwork_set = True
                             InfoCache.add(artist, content, data, api)
                             debug("Downloader::__cache_artists_info(): %s"
-                                  % url)
+                                  % uri)
                         else:
                             InfoCache.add(artist, None, None, api)
                 except Exception as e:
@@ -352,11 +379,9 @@ class Downloader:
                     method = getattr(self, helper)
                     data = method(artist, album)
                     if data is not None:
+                        self.__albums_history.append(album_id)
+                        Lp().art.save_album_artwork(data, album_id)
                         break
-                if data is None:
-                    self.__albums_history.append(album_id)
-                    continue
-                Lp().art.save_album_artwork(data, album_id)
         except Exception as e:
             print("Downloader::__cache_albums_art: %s" % e)
         self.__albums_history.append(album_id)
