@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Gdk, GLib, Gio
+from gi.repository import Gtk, Gdk, GLib, Gio, Gst
 
 from datetime import datetime
 
@@ -58,7 +58,7 @@ class FullScreen(Gtk.Window, InfoController,
         else:
             artsize = int(ArtSize.FULLSCREEN*geometry.height/1920)
         InfoController.__init__(self, artsize)
-
+        widget = builder.get_object("widget")
         self._play_btn = builder.get_object("play_btn")
         self._next_btn = builder.get_object("next_btn")
         self._prev_btn = builder.get_object("prev_btn")
@@ -67,7 +67,14 @@ class FullScreen(Gtk.Window, InfoController,
         self._play_image = builder.get_object("play_image")
         self._pause_image = builder.get_object("pause_image")
         close_btn = builder.get_object("close_btn")
-        close_btn.connect("clicked", self.__destroy)
+        preferences = Gio.Settings.new("org.gnome.desktop.wm.preferences")
+        layout = preferences.get_value("button-layout").get_string()
+        if layout.split(":")[0] == "close":
+            widget.attach(close_btn, 0, 0, 1, 1)
+            close_btn.set_property("halign", Gtk.Align.START)
+        else:
+            widget.attach(close_btn, 2, 0, 1, 1)
+            close_btn.set_property("halign", Gtk.Align.END)
         self._cover = builder.get_object("cover")
         self._title_label = builder.get_object("title")
         self._artist_label = builder.get_object("artist")
@@ -79,7 +86,7 @@ class FullScreen(Gtk.Window, InfoController,
         self._timelabel = builder.get_object("playback")
         self._total_time_label = builder.get_object("duration")
         self.connect("key-release-event", self.__on_key_release_event)
-        self.add(builder.get_object("widget"))
+        self.add(widget)
 
     def do_show(self):
         """
@@ -109,15 +116,14 @@ class FullScreen(Gtk.Window, InfoController,
             self.__timeout2 = GLib.timeout_add(1000,
                                                self.__update_datetime,
                                                show_seconds)
-        self._update_position(Lp().player.position/1000000)
+        self._update_position(Lp().player.position/Gst.SECOND)
         self.fullscreen()
         self._next_popover.set_relative_to(self._album_label)
         if Lp().player.next_track.id != Type.RADIOS:
             self._next_popover.show()
-        # Disable idle
-        self.__cookie = Lp().inhibit(Lp().window,
-                                     Gtk.ApplicationInhibitFlags.IDLE,
-                                     None)
+
+        # Disable screensaver (idle)
+        Lp().inhibitor.manual_inhibit(suspend=False, idle=True)
 
     def do_hide(self):
         """
@@ -139,7 +145,7 @@ class FullScreen(Gtk.Window, InfoController,
             GLib.source_remove(self.__timeout2)
         self._next_popover.set_relative_to(None)
         self._next_popover.hide()
-        Lp().uninhibit(self.__cookie)
+        Lp().inhibitor.manual_uninhibit()
 
     def show_hide_volume_control(self):
         """
@@ -168,6 +174,16 @@ class FullScreen(Gtk.Window, InfoController,
         else:
             self._next_popover.hide()
 
+#######################
+# PROTECTED           #
+#######################
+    def _on_close_button_clicked(self, widget):
+        """
+            Destroy self
+            @param widget as Gtk.Button
+        """
+        self.destroy()
+
 #######################
 # PRIVATE             #
 #######################
@@ -186,13 +202,6 @@ class FullScreen(Gtk.Window, InfoController,
             return False
         return True
 
-    def __destroy(self, widget):
-        """
-            Destroy self
-            @param widget as Gtk.Button
-        """
-        self.destroy()
-
     def __on_key_release_event(self, widget, event):
         """
             Destroy window if Esc
