@@ -13,7 +13,7 @@
 from gi.repository import Gdk, GLib
 from gettext import gettext as _
 
-from lollypop.GioNotify import GioNotify
+from lollypop.thirdparty.GioNotify import GioNotify
 
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.utils import is_gnome
@@ -28,12 +28,13 @@ class NotificationManager:
         """
             Init notification object with lollypop infos
         """
-        self.__inhibitor = False
-        self.__fully_initted = False
         self.__supports_actions = False
+        self.__disable_all_notifications = True
         self.__is_gnome = is_gnome()
-        self.__notification = GioNotify.async_init("Lollypop",
-                                                   self.__on_init_finish)
+        self.__notification = None
+        self.__notification_handler_id = None
+        GioNotify.async_init("Lollypop",
+                             self.__on_init_finish)
 
     def send(self, message, sub=""):
         """
@@ -41,7 +42,8 @@ class NotificationManager:
             @param message as str
             @param sub as str
         """
-        if not self.__fully_initted:
+
+        if self.__disable_all_notifications:
             return
 
         if self.__supports_actions:
@@ -50,27 +52,29 @@ class NotificationManager:
         self.__notification.show_new(
             message,
             sub,
-            "org.gnome.Lollypop",
+            "org.gnome.Lollypop-symbolic",
         )
 
         if self.__supports_actions:
             self.__set_actions()
 
-    def inhibit(self):
-        """
-            Inhibit notifications for one shot
-        """
-        self.__inhibitor = True
-
 #######################
 # PRIVATE             #
 #######################
 
-    def __on_init_finish(self, caps):
+    def __on_init_finish(self, notification, server_info, caps, error=None):
         """
             Set actions and connect signals
+            @param notification as GioNotify
+            @param server_info as {}
             @param caps as [str]
         """
+        if error is not None:
+            print("notification::__on_init_finish():", error)
+            return
+
+        self.__notification = notification
+
         self.__notification.set_hint(
             "category",
             GLib.Variant("s", "x-gnome.music"),
@@ -97,12 +101,17 @@ class NotificationManager:
             self.__supports_actions = True
             self.__set_actions()
 
-        Lp().player.connect(
-            "current-changed",
-            self.__on_current_changed,
+        self.__on_notifications_settings_changed()
+
+        Lp().settings.connect(
+            "changed::disable-song-notifications",
+            self.__on_notifications_settings_changed,
         )
 
-        self.__fully_initted = True
+        Lp().settings.connect(
+            "changed::disable-notifications",
+            self.__on_notifications_settings_changed,
+        )
 
     def __set_actions(self):
         """
@@ -126,9 +135,6 @@ class NotificationManager:
             Send notification with track_id infos
             @param player Player
         """
-        if player.current_track.title == "" or self.__inhibitor:
-            self.__inhibitor = False
-            return
         state = Lp().window.get_window().get_state()
         if player.current_track.id is None or\
                 state & Gdk.WindowState.FOCUSED or\
@@ -163,3 +169,23 @@ class NotificationManager:
                 ("<b>" + ", ".join(player.current_track.artists) + "</b>",
                  "<i>" + player.current_track.album.name + "</i>"),
                 cover_path)
+
+    def __on_notifications_settings_changed(self, *ignore):
+        self.__disable_all_notifications = Lp().settings.get_value(
+            "disable-notifications",
+        )
+
+        disable_song_notifications = Lp().settings.get_value(
+            "disable-song-notifications",
+        )
+
+        if self.__notification_handler_id:
+            Lp().player.disconnect(self.__notification_handler_id)
+            self.__notification_handler_id = None
+
+        if (not self.__disable_all_notifications and not
+                disable_song_notifications):
+            self.__notification_handler_id = Lp().player.connect(
+                "current-changed",
+                self.__on_current_changed,
+            )
