@@ -115,6 +115,7 @@ class Base:
             radios.set_rate(self._album_artists[0], rate)
         else:
             self.db.set_rate(self.id, rate)
+            Lp().player.emit("rate-changed", (self.id, rate))
 
 
 class Disc:
@@ -242,14 +243,6 @@ class Album(Base):
             self._tracks = [Track(track_id) for track_id in self.track_ids]
         return self._tracks
 
-    @property
-    def is_web(self):
-        """
-            True if a web stream
-            @return bool
-        """
-        return self.synced == Type.NONE
-
     def disc_names(self, disc):
         """
             Disc names
@@ -312,10 +305,10 @@ class Track(Base):
     """
         Represent a track
     """
-    FIELDS = ["name", "album_id", "album_artist_ids",
-              "artist_ids", "genre_ids", "album_name", "artists", "genres",
+    FIELDS = ["name", "album_id", "album_artist_ids", "artist_ids",
+              "genre_ids", "popularity", "album_name", "artists", "genres",
               "duration", "number", "year", "persistent", "mtime"]
-    DEFAULTS = ["", None, [], [], [], "", "", "", 0.0, 0, None, 1, 0]
+    DEFAULTS = ["", None, [], [], [], 0, "", "", "", 0.0, 0, None, 1, 0]
 
     def __init__(self, track_id=None):
         """
@@ -327,30 +320,6 @@ class Track(Base):
         self._uri = None
         self._non_album_artists = []
 
-    @property
-    def is_web(self):
-        """
-            True if a web stream
-            @return bool
-        """
-        return self.is_jgm or self.is_youtube
-
-    @property
-    def is_jgm(self):
-        """
-            True if a jgm stream
-            @return bool
-        """
-        return self.uri.startswith("http://app.jgm90.com")
-
-    @property
-    def is_youtube(self):
-        """
-            True if a youtube stream
-            @return bool
-        """
-        return self.uri.startswith("https://www.youtube.com")
-
     @property
     def non_album_artists(self):
         """
