@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gio, GLib, Gst
+from gi.repository import Gst
 
 from pickle import load
 from random import choice
@@ -24,7 +24,7 @@ from lollypop.player_externals import ExternalsPlayer
 from lollypop.player_userplaylist import UserPlaylistPlayer
 from lollypop.radios import Radios
 from lollypop.objects import Track, Album
-from lollypop.define import Lp, Type, NextContext, DataPath, Shuffle
+from lollypop.define import Lp, Type, NextContext, LOLLYPOP_DATA_PATH, Shuffle
 
 
 class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
@@ -103,19 +103,9 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             @param play as bool, ignored for radios
         """
         if track.id == Type.RADIOS:
-            if not Lp().scanner.is_locked():
-                Lp().window.pulse(False)
-                Lp().window.pulse(True)
             RadioPlayer.load(self, track)
         else:
             if play:
-                if track.is_web and\
-                        not Gio.NetworkMonitor.get_default(
-                                                     ).get_network_available():
-                    self._current_track = track
-                    self.set_next()
-                    GLib.idle_add(self.next)
-                    return
                 # Do not update next if user clicked on a track
                 if self.is_party and track != self._next_track:
                     self.__do_not_update_next = True
@@ -313,9 +303,6 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         # We are in compilation view without genre
         elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
             self._albums = Lp().albums.get_compilation_ids()
-        # We are in charts view with a genre
-        elif artist_ids and artist_ids[0] == Type.CHARTS:
-            self._albums = Lp().albums.get_charts_ids(genre_ids)
         # Add albums for artists/genres
         else:
             # If we are not in compilation view and show compilation is on,
@@ -375,10 +362,14 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         """
         try:
             if Lp().settings.get_value("save-state"):
-                track_id = load(open(DataPath + "/track_id.bin", "rb"))
-                playlist_ids = load(open(DataPath + "/playlist_ids.bin",
-                                    "rb"))
-                (is_playing, was_party) = load(open(DataPath + "/player.bin",
+                track_id = load(open(LOLLYPOP_DATA_PATH +
+                                     "/track_id.bin",
+                                     "rb"))
+                playlist_ids = load(open(LOLLYPOP_DATA_PATH +
+                                         "/playlist_ids.bin",
+                                         "rb"))
+                (is_playing, was_party) = load(open(LOLLYPOP_DATA_PATH +
+                                                    "/player.bin",
                                                     "rb"))
                 if playlist_ids and playlist_ids[0] == Type.RADIOS:
                     radios = Radios()
@@ -422,14 +413,17 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
                             self.emit("party-changed", True)
                         else:
                             self._albums = load(open(
-                                                DataPath + "/albums.bin",
+                                                LOLLYPOP_DATA_PATH +
+                                                "/albums.bin",
                                                 "rb"))
                             self.shuffle_albums(True)
                             self._context.genre_ids = load(open(
-                                                DataPath + "/genre_ids.bin",
+                                                LOLLYPOP_DATA_PATH +
+                                                "/genre_ids.bin",
                                                 "rb"))
                             self._context.artist_ids = load(open(
-                                                DataPath + "/artist_ids.bin",
+                                                LOLLYPOP_DATA_PATH +
+                                                "/artist_ids.bin",
                                                 "rb"))
                     self.set_next()
                     self.set_prev()
@@ -518,8 +512,6 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             # Get a linear track then
             if next_track.id is None:
                 next_track = LinearPlayer.next(self)
-            if next_track.is_web:
-                self._load_web(next_track, False)
             self._next_track = next_track
             self.emit("next-changed")
         except Exception as e:
@@ -555,6 +547,15 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
 #######################
 # PROTECTED           #
 #######################
+    def _on_bus_error(self, bus, message):
+        """
+            Pass error to Bin/Radio
+            @param bus as Gst.Bus
+            @param message as Gst.Message
+        """
+        BinPlayer._on_bus_error(self, bus, message)
+        RadioPlayer._on_bus_error(self, bus, message)
+
     def _on_stream_start(self, bus, message):
         """
             On stream start, set next and previous track
