@@ -13,16 +13,14 @@
 from gi.repository import Gst, GstAudio, GstPbutils, GLib
 
 from time import time
-from threading import Thread
 
 from lollypop.player_base import BasePlayer
 from lollypop.tagreader import TagReader
 from lollypop.player_plugins import PluginsPlayer
 from lollypop.define import GstPlayFlags, NextContext, Lp
 from lollypop.codecs import Codecs
-from lollypop.define import Type, DbPersistent
-from lollypop.utils import debug, get_network_available
-from lollypop.objects import Track
+from lollypop.define import Type
+from lollypop.utils import debug
 
 
 class BinPlayer(BasePlayer):
@@ -51,14 +49,14 @@ class BinPlayer(BasePlayer):
             playbin.set_property("buffer-size", 5 << 20)
             playbin.set_property("buffer-duration", 10 * Gst.SECOND)
             playbin.connect("about-to-finish",
-                            self.__on_stream_about_to_finish)
+                            self._on_stream_about_to_finish)
             bus = playbin.get_bus()
             bus.add_signal_watch()
-            bus.connect("message::error", self.__on_bus_error)
-            bus.connect("message::eos", self.__on_bus_eos)
-            bus.connect("message::element", self.__on_bus_element)
+            bus.connect("message::error", self._on_bus_error)
+            bus.connect("message::eos", self._on_bus_eos)
+            bus.connect("message::element", self._on_bus_element)
             bus.connect("message::stream-start", self._on_stream_start)
-            bus.connect("message::tag", self.__on_bus_message_tag)
+            bus.connect("message::tag", self._on_bus_message_tag)
         self._start_time = 0
 
     @property
@@ -252,49 +250,12 @@ class BinPlayer(BasePlayer):
         debug("BinPlayer::_load_track(): %s" % track.uri)
         try:
             self._current_track = track
-            if track.is_web:
-                loaded = self._load_web(track)
-                # If track not loaded, go next
-                if not loaded:
-                    self.set_next()
-                    GLib.timeout_add(500, self.__load,
-                                     self.next_track, init_volume)
-                return False  # Return not loaded as handled by load_web()
-            else:
-                self._playbin.set_property("uri", track.uri)
+            self._playbin.set_property("uri", track.uri)
         except Exception as e:  # Gstreamer error
             print("BinPlayer::_load_track(): ", e)
             return False
         return True
 
-    def _load_web(self, track, play=True):
-        """
-            Load track url and play it
-            @param track as Track
-            @param play as bool
-            @return True if loading
-        """
-        if not get_network_available():
-            # Force widgets to update (spinners)
-            self.emit("current-changed")
-            return False
-        try:
-            from lollypop.web import Web
-            if play:
-                self.emit("loading-changed", True)
-            t = Thread(target=Web.play_track,
-                       args=(track, play, self.__set_gv_uri))
-            t.daemon = True
-            t.start()
-            return True
-        except Exception as e:
-            self._current_track = Track()
-            self.stop()
-            self.emit("current-changed")
-            if Lp().notify is not None:
-                Lp().notify.send(str(e), track.uri)
-            print("PlayerBin::_load_web()", e)
-
     def _scrobble(self, finished, finished_start_time):
         """
             Scrobble on lastfm
@@ -305,7 +266,7 @@ class BinPlayer(BasePlayer):
         if finished.duration < 30:
             return
         # Scrobble on lastfm
-        if Lp().lastfm is not None:
+        if Lp().lastfm is not None and Lp().lastfm.session_key:
             artists = ", ".join(finished.artists)
             played = time() - finished_start_time
             # We can scrobble if the track has been played
@@ -315,6 +276,17 @@ class BinPlayer(BasePlayer):
                                         finished.album_name,
                                         finished.title,
                                         int(finished_start_time))
+        # Scrobble on librefm
+        if Lp().librefm is not None and Lp().librefm.session_key:
+            artists = ", ".join(finished.artists)
+            played = time() - finished_start_time
+            # We can scrobble if the track has been played
+            # for at least half its duration, or for 4 minutes
+            if played >= finished.duration / 2 or played >= 240:
+                Lp().librefm.do_scrobble(artists,
+                                         finished.album_name,
+                                         finished.title,
+                                         int(finished_start_time))
 
     def _on_stream_start(self, bus, message):
         """
@@ -327,7 +299,10 @@ class BinPlayer(BasePlayer):
         debug("Player::_on_stream_start(): %s" % self._current_track.uri)
         self.emit("current-changed")
         # Update now playing on lastfm
-        if Lp().lastfm is not None and self._current_track.id >= 0:
+        # Not supported by librefm
+        if Lp().lastfm is not None and\
+                Lp().lastfm.session_key and\
+                self._current_track.id >= 0:
             artists = ", ".join(self._current_track.artists)
             Lp().lastfm.now_playing(artists,
                                     self._current_track.album_name,
@@ -340,24 +315,122 @@ class BinPlayer(BasePlayer):
         except:  # Locked database
             pass
 
+    def _on_bus_message_tag(self, bus, message):
+        """
+            Read tags from stream
+            @param bus as Gst.Bus
+            @param message as Gst.Message
+        """
+        # Some radio streams send message tag every seconds!
+        changed = False
+        if self._current_track.id >= 0 or self._current_track.duration > 0.0:
+            return
+        debug("Player::__on_bus_message_tag(): %s" % self._current_track.uri)
+        reader = TagReader()
+        tags = message.parse_tag()
+        title = reader.get_title(tags, "")
+        if title != "" and self._current_track.name != title:
+            self._current_track.name = title
+            changed = True
+        if self._current_track.name == "":
+            self._current_track.name = self._current_track.uri
+            changed = True
+        artists = reader.get_artists(tags)
+        if artists != "" and self._current_track.artists != artists:
+            self._current_track.artists = artists.split(",")
+            changed = True
+        if not self._current_track.artists:
+            self._current_track.artists = self._current_track.album_artists
+            changed = True
+
+        if self._current_track.id == Type.EXTERNALS:
+            (b, duration) = self._playbin.query_duration(Gst.Format.TIME)
+            if b:
+                self._current_track.duration = duration/1000000000
+            # We do not use tagreader as we need to check if value is None
+            self._current_track.album_name = tags.get_string_index("album",
+                                                                   0)[1]
+            if self._current_track.album_name is None:
+                self._current_track.album_name = ""
+            self._current_track.genres = reader.get_genres(tags).split(",")
+            changed = True
+        if changed:
+            self.emit("current-changed")
+
+    def _on_bus_element(self, bus, message):
+        """
+            Set elements for missings plugins
+            @param bus as Gst.Bus
+            @param message as Gst.Message
+        """
+        if GstPbutils.is_missing_plugin_message(message):
+            self.__codecs.append(message)
+
+    def _on_bus_error(self, bus, message):
+        """
+            Try a codec install and update current track
+            @param bus as Gst.Bus
+            @param message as Gst.Message
+        """
+        debug("Error playing: %s" % self._current_track.uri)
+        Lp().window.pulse(False)
+        if self.__codecs.is_missing_codec(message):
+            self.__codecs.install()
+            Lp().scanner.stop()
+        elif Lp().notify is not None:
+            Lp().notify.send(message.parse_error()[0].message)
+        self.stop()
+
+    def _on_bus_eos(self, bus, message):
+        """
+            On end of stream, stop playback
+            go next otherwise
+        """
+        debug("Player::__on_bus_eos(): %s" % self._current_track.uri)
+        if self._playbin.get_bus() == bus:
+            self.stop()
+            self._next_context = NextContext.NONE
+            if self._next_track.id is not None:
+                self._load_track(self._next_track)
+            self.emit("current-changed")
+
+    def _on_stream_about_to_finish(self, playbin):
+        """
+            When stream is about to finish, switch to next track without gap
+            @param playbin as Gst bin
+        """
+        debug("Player::__on_stream_about_to_finish(): %s" % playbin)
+        # Don"t do anything if crossfade on, track already changed
+        if self._crossfading:
+            return
+        if self._current_track.id == Type.RADIOS:
+            return
+        self._scrobble(self._current_track, self._start_time)
+        # Increment popularity
+        if not Lp().scanner.is_locked() and self._current_track.id >= 0:
+            Lp().tracks.set_more_popular(self._current_track.id)
+            # In party mode, linear popularity
+            if self.is_party:
+                pop_to_add = 1
+            # In normal mode, based on tracks count
+            else:
+                # Some users report an issue where get_tracks_count() return 0
+                # See issue #886
+                # Don"t understand how this can happen!
+                count = Lp().albums.get_tracks_count(
+                                                 self._current_track.album_id)
+                if count:
+                    pop_to_add = int(Lp().albums.max_count / count)
+                else:
+                    pop_to_add = 1
+            Lp().albums.set_more_popular(self._current_track.album_id,
+                                         pop_to_add)
+        if self._next_track.id is not None:
+            self._load_track(self._next_track)
+
 #######################
 # PRIVATE             #
 #######################
-    def __update_current_duration(self, reader, track):
-        """
-            Update current track duration
-            @param reader as TagReader
-            @param track id as int
-        """
-        try:
-            duration = reader.get_info(track.uri).get_duration() / 1000000000
-            if duration != track.duration and duration > 0:
-                Lp().tracks.set_duration(track.id, duration)
-                self._current_track.set_duration(duration)
-                GLib.idle_add(self.emit, "duration-changed", track.id)
-        except:
-            pass
-
     def __load(self, track, init_volume=True):
         """
             Stop current track, load track id and play it
@@ -508,131 +581,6 @@ class BinPlayer(BasePlayer):
             self.__playbin1.set_volume(GstAudio.StreamVolumeFormat.CUBIC, vol)
         self.emit("volume-changed")
 
-    def __on_bus_message_tag(self, bus, message):
-        """
-            Read tags from stream
-            @param bus as Gst.Bus
-            @param message as Gst.Message
-        """
-        # Some radio streams send message tag every seconds!
-        changed = False
-        if self._current_track.persistent == DbPersistent.INTERNAL and\
-            (self._current_track.id >= 0 or
-             self._current_track.duration > 0.0):
-            return
-        debug("Player::__on_bus_message_tag(): %s" % self._current_track.uri)
-        reader = TagReader()
-
-        # Update duration of non internals
-        if self._current_track.persistent != DbPersistent.INTERNAL:
-            t = Thread(target=self.__update_current_duration,
-                       args=(reader, self._current_track))
-            t.daemon = True
-            t.start()
-            return
-
-        tags = message.parse_tag()
-        title = reader.get_title(tags, "")
-        if title != "" and self._current_track.name != title:
-            self._current_track.name = title
-            changed = True
-        if self._current_track.name == "":
-            self._current_track.name = self._current_track.uri
-            changed = True
-        artists = reader.get_artists(tags)
-        if artists != "" and self._current_track.artists != artists:
-            self._current_track.artists = artists.split(",")
-            changed = True
-        if not self._current_track.artists:
-            self._current_track.artists = self._current_track.album_artists
-            changed = True
-
-        if self._current_track.id == Type.EXTERNALS:
-            (b, duration) = self._playbin.query_duration(Gst.Format.TIME)
-            if b:
-                self._current_track.duration = duration/1000000000
-            # We do not use tagreader as we need to check if value is None
-            self._current_track.album_name = tags.get_string_index("album",
-                                                                   0)[1]
-            if self._current_track.album_name is None:
-                self._current_track.album_name = ""
-            self._current_track.genres = reader.get_genres(tags).split(",")
-            changed = True
-        if changed:
-            self.emit("current-changed")
-
-    def __on_bus_element(self, bus, message):
-        """
-            Set elements for missings plugins
-            @param bus as Gst.Bus
-            @param message as Gst.Message
-        """
-        if GstPbutils.is_missing_plugin_message(message):
-            self.__codecs.append(message)
-
-    def __on_bus_error(self, bus, message):
-        """
-            Handle first bus error, ignore others
-            @param bus as Gst.Bus
-            @param message as Gst.Message
-        """
-        debug("Error playing: %s" % self._current_track.uri)
-        Lp().window.pulse(False)
-        if self.__codecs.is_missing_codec(message):
-            self.__codecs.install()
-            Lp().scanner.stop()
-        elif Lp().notify is not None:
-            Lp().notify.send(message.parse_error()[0].message)
-        self.emit("current-changed")
-        return True
-
-    def __on_bus_eos(self, bus, message):
-        """
-            On end of stream, stop playback
-            go next otherwise
-        """
-        debug("Player::__on_bus_eos(): %s" % self._current_track.uri)
-        if self._playbin.get_bus() == bus:
-            self.stop()
-            self._next_context = NextContext.NONE
-            if self._next_track.id is not None:
-                self._load_track(self._next_track)
-            self.emit("current-changed")
-
-    def __on_stream_about_to_finish(self, playbin):
-        """
-            When stream is about to finish, switch to next track without gap
-            @param playbin as Gst bin
-        """
-        debug("Player::__on_stream_about_to_finish(): %s" % playbin)
-        # Don"t do anything if crossfade on, track already changed
-        if self._crossfading:
-            return
-        if self._current_track.id == Type.RADIOS:
-            return
-        self._scrobble(self._current_track, self._start_time)
-        # Increment popularity
-        if not Lp().scanner.is_locked() and self._current_track.id >= 0:
-            Lp().tracks.set_more_popular(self._current_track.id)
-            # In party mode, linear popularity
-            if self.is_party:
-                pop_to_add = 1
-            # In normal mode, based on tracks count
-            else:
-                # Some users report an issue where get_tracks_count() return 0
-                # See issue #886
-                # Don"t understand how this can happen!
-                count = Lp().albums.get_tracks_count(
-                                                 self._current_track.album_id)
-                if count:
-                    pop_to_add = int(Lp().albums.max_count / count)
-                else:
-                    pop_to_add = 1
-            Lp().albums.set_more_popular(self._current_track.album_id,
-                                         pop_to_add)
-        if self._next_track.id is not None:
-            self._load_track(self._next_track)
-
     def __set_gv_uri(self, uri, track, play):
         """
             Play uri for io
