@@ -10,17 +10,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gio, Gdk, GdkPixbuf
+from gi.repository import Gtk, GLib, Gio, Gdk
 
-from gettext import gettext as _
-from threading import Thread
-
-from lollypop.define import Lp, ArtSize, Type, DbPersistent
+from lollypop.define import Lp, ArtSize, Type
 from lollypop.objects import Track, Album
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.view_albums import AlbumBackView
-from lollypop.utils import noaccents, get_network_available
-from lollypop.lio import Lio
+from lollypop.utils import noaccents
+from lollypop.helper_task import TaskHelper
+from lollypop.search import Search
 
 
 class SearchRow(Gtk.ListBoxRow):
@@ -36,18 +34,10 @@ class SearchRow(Gtk.ListBoxRow):
         """
         Gtk.ListBoxRow.__init__(self)
         self.__item = item
-        self.__uri_set = False
         self.__score = None
         builder = Gtk.Builder()
-        if internal:
-            builder.add_from_resource(
-                                    "/org/gnome/Lollypop/InternalSearchRow.ui")
-            self.__progress = None
-        else:
-            builder.add_from_resource(
-                                    "/org/gnome/Lollypop/ExternalSearchRow.ui")
-            self.__progress = builder.get_object("progress")
-            self.__stack = builder.get_object("stack")
+        builder.add_from_resource("/org/gnome/Lollypop/InternalSearchRow.ui")
+        self.__stack = builder.get_object("stack")
         builder.connect_signals(self)
         self.set_property("has-tooltip", True)
         self.connect("query-tooltip", self.__on_query_tooltip)
@@ -148,47 +138,11 @@ class SearchRow(Gtk.ListBoxRow):
         surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf,
                                                        self.get_scale_factor(),
                                                        None)
-        del pixbuf
         self.__cover.set_from_surface(surface)
-        del surface
-
-    @property
-    def is_loading(self):
-        """
-            True if is loading a track/album
-            @return bool
-        """
-        return self.__progress is not None and\
-            self.__progress.get_opacity() == 1
-
-    def on_activated(self, persistent):
-        """
-            Download item
-            @param persistent as DbPersistent
-        """
-        from lollypop.web import Web
-        web = Web()
-        web.connect("saved", self.__on_saved, persistent)
-        if self.__item.is_track:
-            web.save_track(self.__item, persistent)
-        else:
-            web.save_album(self.__item, persistent)
-            if self.__progress is not None:
-                self.__progress.set_opacity(1)
-            web.connect("progress", self.__on_progress)
-        self.__stack.set_visible_child_name("spinner")
-        self.__stack.get_visible_child().start()
 
 #######################
 # PROTECTED           #
 #######################
-    def _on_save_clicked(self, button):
-        """
-            Save into collection
-            @param button as Gtk.Button
-        """
-        self.on_activated(DbPersistent.EXTERNAL)
-
     def _on_playlist_clicked(self, button):
         """
             Prepend track to queue
@@ -245,39 +199,8 @@ class SearchRow(Gtk.ListBoxRow):
                                                  ArtSize.MEDIUM,
                                                  self.get_scale_factor())
         self.__cover.set_from_surface(surface)
-        del surface
         self.__artist.set_text(", ".join(artists))
 
-    def __on_saved(self, web, item_id, persistent):
-        """
-            Play track
-            @param web as Web
-            @param item id as int
-            @parma activated as DbPersistent
-        """
-        if self.__progress is not None:
-            self.__progress.set_opacity(0)
-        self.__item.id = item_id
-        if persistent == DbPersistent.NONE:
-            if self.__item.is_track:
-                Lp().player.emit("loading-changed", True)
-            self.emit("activate")
-        # If no visible widget in stack, self destroyed
-        visible = self.__stack.get_visible_child()
-        if visible is not None:
-            visible.stop()
-            self.__stack.set_visible_child_name("save")
-            self.__stack.get_visible_child().set_sensitive(False)
-
-    def __on_progress(self, web, progress):
-        """
-            Update progress bar
-            @param web as Web
-            @param progress as float
-        """
-        if self.__progress is not None:
-            self.__progress.set_fraction(progress)
-
     def __on_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
             Show tooltip if needed
@@ -310,10 +233,9 @@ class SearchPopover(Gtk.Popover):
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect("map", self.__on_map)
         self.connect("unmap", self.__on_unmap)
-        self.__timeout = None
+        self.__timeout_id = None
         self.__current_search = ""
-        self.__nsearch = None
-        self.__lsearch = None
+        self.__cancellable = Gio.Cancellable()
         self.__history = []
 
         builder = Gtk.Builder()
@@ -333,12 +255,6 @@ class SearchPopover(Gtk.Popover):
         self.__spinner = builder.get_object("spinner")
         self.__header_stack = builder.get_object("stack")
 
-        self.__switch = builder.get_object("search-switch")
-        if GLib.find_program_in_path("youtube-dl") is None:
-            self.__switch.set_tooltip_text(_("You need to install youtube-dl"))
-        else:
-            self.__switch.set_state(Lp().settings.get_value("network-search"))
-
         self.__scrolled = builder.get_object("scrolled")
         self.__scrolled.add(self.__view)
         # Connect here because we don"t want previous switch.set_state()
@@ -366,48 +282,31 @@ class SearchPopover(Gtk.Popover):
             Create a new playlist based on search
             @param button as Gtk.Button
         """
-        t = Thread(target=self.__new_playlist)
-        t.daemon = True
-        t.start()
+        helper = TaskHelper()
+        helper.run(self.__new_playlist)
 
     def _on_search_changed(self, widget):
         """
             Timeout filtering
             @param widget as Gtk.TextEntry
         """
-        self.__reset_search()
-        if self.__timeout:
-            GLib.source_remove(self.__timeout)
-            self.__timeout = None
+        self.__cancellable.reset()
+        if self.__timeout_id:
+            GLib.source_remove(self.__timeout_id)
+            self.__timeout_id = None
 
         self.__current_search = widget.get_text().strip()
         if self.__current_search != "":
             self.__new_btn.set_sensitive(True)
-            self.__timeout = GLib.timeout_add(500,
-                                              self.__on_search_changed_thread)
+            self.__timeout_id = GLib.timeout_add(
+                                              200,
+                                              self.__on_search_changed_timeout)
         else:
             self.__new_btn.set_sensitive(False)
 
-    def _on_state_set(self, switch, state):
-        """
-            Save state
-            @param switch as Gtk.switch
-            @param state as bool
-        """
-        Lp().settings.set_boolean("network-search", state)
-        GLib.idle_add(self._on_search_changed, self.__entry)
-
 #######################
 # PRIVATE             #
 #######################
-    def __enable_network_search(self):
-        """
-            True if shoud enable network search
-            @return bool
-        """
-        return GLib.find_program_in_path("youtube-dl") is not None and\
-            get_network_available()
-
     def __calculate_score(self, row):
         """
             Calculate score for row
@@ -415,15 +314,10 @@ class SearchPopover(Gtk.Popover):
         """
         if row.score is not None:
             return
-        # Network search score less
-        if row.id is None:
-            score = 0
-            artists = row.artists
-        else:
-            score = 1
-            artists = []
-            for artist_id in row.artist_ids:
-                artists.append(Lp().artists.get_name(artist_id))
+        score = 0
+        artists = []
+        for artist_id in row.artist_ids:
+            artists.append(Lp().artists.get_name(artist_id))
 
         for item in self.__current_search.split():
             try:
@@ -455,78 +349,34 @@ class SearchPopover(Gtk.Popover):
         self.__calculate_score(row2)
         return row1.score < row2.score
 
-    def __clear(self, rows):
+    def __clear(self):
         """
-            Clear search view
-            @param items as [SearchRow]
-            @warning not thread safe
+            Clear view
         """
-        if rows:
-            row = rows.pop(0)
-            self.__view.remove(row)
-            row.destroy()
-            GLib.idle_add(self.__clear, rows)
+        self.__view.forall(lambda x: self.__view.remove(x))
 
     def __populate(self):
         """
             Populate searching items
             in db based on text entry current text
         """
+        self.__clear()
         self.__header_stack.set_visible_child(self.__spinner)
         self.__spinner.start()
         self.__history = []
-        # Network Search
-        if self.__need_network_search():
-            t = Thread(target=self.__nsearch.do, args=(self.__current_search,))
-            t.daemon = True
-            t.start()
-
-        # Local Search
         search_items = [self.__current_search]
         for item in self.__current_search.split():
-            if len(item) >= 3:
+            if len(item) >= 3 and item not in search_items:
                 search_items.append(item)
-        GLib.idle_add(self.__clear, self.__view.get_children())
-        t = Thread(target=self.__lsearch.do, args=(search_items,))
-        t.daemon = True
-        t.start()
+        search = Search()
+        search.get(search_items,
+                   self.__cancellable,
+                   callback=(self.__on_search_get,))
 
-    def __download_cover(self, uri, row):
-        """
-            Download row covers
-            @param uri as str
-            @param row as SearchRow
-        """
-        try:
-            f = Lio.File.new_for_uri(uri)
-            (status, data, tag) = f.load_contents(None)
-            if status:
-                stream = Gio.MemoryInputStream.new_from_data(data,
-                                                             None)
-                pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
-                                                   stream,
-                                                   ArtSize.MEDIUM,
-                                                   -1,
-                                                   True,
-                                                   None)
-                stream.close()
-                GLib.idle_add(row.set_cover, pixbuf)
-        except:
-            pass
-
-    def __populate_user_playlist_by_tracks(self, track_ids, track_id):
-        """
-            Set user playlist
-            @param track_ids as [int]
-            @param track id as int
-            @thread safe
-        """
-        Lp().player.load(Track(track_id))
-        Lp().player.populate_user_playlist_by_tracks(track_ids, [Type.SEARCH])
-
-    def __new_playlist(self):
+    def __new_playlist(self, params):
         """
             Create a new playlist based on search
+            @params as ()
         """
         tracks = []
         for child in self.__view.get_children():
@@ -544,82 +394,27 @@ class SearchPopover(Gtk.Popover):
                 playlist_id = Lp().playlists.get_id(self.__current_search)
             Lp().playlists.add_tracks(playlist_id, tracks)
 
-    def __reset_search(self):
-        """
-            Reset search object
-        """
-        self.__header_stack.set_visible_child(self.__new_btn)
-        self.__spinner.stop()
-        if self.__nsearch is not None:
-            self.__nsearch.disconnect_by_func(self.__on_network_item_found)
-            self.__nsearch.stop()
-            self.__nsearch = None
-        if self.__lsearch is not None:
-            self.__lsearch.disconnect_by_func(self.__on_local_item_found)
-            self.__lsearch.stop()
-            self.__lsearch = None
-
-    def __need_network_search(self):
-        """
-            Return True if network search needed
-            @return True
-        """
-        return Lp().settings.get_value("network-search") and\
-            GLib.find_program_in_path("youtube-dl") is not None
-
-    def __on_local_item_found(self, search):
+    def __on_search_get(self, items):
         """
             Add rows for internal results
-            @param search as LocalSearch
+            @param items as [SearchItem]
         """
-        if self.__lsearch != search:
-            return
-        if not search.items:
-            if self.__lsearch.finished and\
-                    (self.__nsearch is None or self.__nsearch.finished):
-                self.__header_stack.set_visible_child(self.__new_btn)
-                self.__spinner.stop()
-            return
-        item = search.items.pop(0)
-        search_row = SearchRow(item)
-        search_row.show()
-        self.__view.add(search_row)
-
-    def __on_network_item_found(self, search):
-        """
-            Add rows for internal results
-            @param search as NetworkSearch
-        """
-        if self.__nsearch != search:
-            return
-        if not search.items:
-            if self.__nsearch.finished and self.__lsearch.finished:
-                self.__header_stack.set_visible_child(self.__new_btn)
-                self.__spinner.stop()
-            return
-        item = search.items.pop(0)
-        if item.exists_in_db()[0]:
-            return
-        if item.is_track:
-            history = "♫" + item.name + item.artists[0]
-        else:
-            history = item.name + item.artists[0]
-        if history.lower() not in self.__history:
-            self.__history.append(history.lower())
-            search_row = SearchRow(item, False)
+        if items:
+            item = items.pop(0)
+            search_row = SearchRow(item)
             search_row.show()
             self.__view.add(search_row)
-            t = Thread(target=self.__download_cover,
-                       args=(item.smallcover, search_row))
-            t.daemon = True
-            t.start()
+            GLib.idle_add(self.__on_search_get, items)
+        else:
+            GLib.idle_add(self.__spinner.stop)
+            GLib.idle_add(self.__header_stack.set_visible_child,
+                          self.__new_btn)
 
     def __on_map(self, widget):
         """
             Disable global shortcuts and resize
             @param widget as Gtk.Widget
         """
-        self.__switch.set_sensitive(self.__enable_network_search())
         # FIXME Not needed with GTK >= 3.18
         Lp().window.enable_global_shortcuts(False)
         height = Lp().window.get_size()[1]
@@ -632,23 +427,17 @@ class SearchPopover(Gtk.Popover):
         """
         # FIXME Not needed with GTK >= 3.18
         Lp().window.enable_global_shortcuts(True)
-        self.__reset_search()
+        self.__cancellable.cancel()
         self.__header_stack.set_visible_child(self.__new_btn)
         self.__spinner.stop()
 
-    def __on_search_changed_thread(self):
+    def __on_search_changed_timeout(self):
         """
             Populate widget
         """
-        self.__reset_search()
-        from lollypop.search_local import LocalSearch
-        from lollypop.search_network import NetworkSearch
-        self.__timeout = None
-        self.__lsearch = LocalSearch()
-        self.__lsearch.connect("item-found", self.__on_local_item_found)
-        if self.__need_network_search():
-            self.__nsearch = NetworkSearch()
-            self.__nsearch.connect("item-found", self.__on_network_item_found)
+        self.__timeout_id = None
+        self.__cancellable.cancel()
+        self.__cancellable.reset()
         self.__populate()
 
     def __on_row_activated(self, widget, row):
@@ -657,11 +446,7 @@ class SearchPopover(Gtk.Popover):
             @param widget as Gtk.ListBox
             @param row as SearchRow
         """
-        if row.is_loading:
-            return
-        if row.id is None:
-            row.on_activated(DbPersistent.NONE)
-        elif row.is_track:
+        if row.is_track:
             # Add to queue, and play (so remove from queue)
             # Allow us to not change user current playlist
             if not Lp().player.is_party:
