@@ -77,13 +77,10 @@ class SelectionList(Gtk.Overlay):
         self.__scrolled.add(self.__view)
         self.__scrolled.show()
         self.add(self.__scrolled)
-        if Gtk.get_minor_version() > 14:
-            self.__fast_scroll = FastScroll(self.__view,
-                                            self.__model,
-                                            self.__scrolled)
-            self.add_overlay(self.__fast_scroll)
-        else:
-            self.__fast_scroll = None
+        self.__fast_scroll = FastScroll(self.__view,
+                                        self.__model,
+                                        self.__scrolled)
+        self.add_overlay(self.__fast_scroll)
         self.__scrolled.connect("enter-notify-event", self.__on_enter_notify)
         self.__scrolled.connect("leave-notify-event", self.__on_leave_notify)
 
@@ -290,11 +287,9 @@ class SelectionList(Gtk.Overlay):
             items.append((Type.LOVED, _("Loved albums")))
         items.append((Type.RECENTS, _("Recently added albums")))
         items.append((Type.RANDOMS, _("Random albums")))
+        items.append((Type.NEVER, _("Never played albums")))
         items.append((Type.PLAYLISTS, _("Playlists")))
         items.append((Type.RADIOS, _("Radios")))
-        if Lp().settings.get_value("show-charts") and\
-                Lp().settings.get_value("network-access"):
-            items.append((Type.CHARTS, _("The charts")))
         if self.__is_artists:
             items.append((Type.ALL, _("All albums")))
         else:
@@ -467,15 +462,7 @@ class SelectionList(Gtk.Overlay):
         elif object_id == Type.LOVED:
             icon = "emblem-favorite-symbolic"
         elif object_id == Type.NEVER:
-            icon = "document-new-symbolic"
-        elif object_id == Type.CHARTS:
-            icon = "application-rss+xml-symbolic"
-        elif object_id == Type.SPOTIFY:
-            icon = "lollypop-spotify-symbolic"
-        elif object_id == Type.ITUNES:
-            icon = "lollypop-itunes-symbolic"
-        elif object_id == Type.LASTFM:
-            icon = "lollypop-lastfm-symbolic"
+            icon = "audio-speakers-symbolic"
         elif object_id == Type.NOPARTY:
             icon = "emblem-music-symbolic"
         return icon
