@@ -10,15 +10,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gst, GstPbutils, GLib
+from gi.repository import Gst, GstPbutils, GLib, Gio
 
 from re import match
 
 from gettext import gettext as _
 
-from lollypop.define import Lp
-from lollypop.utils import format_artist_name, decode_all
-from lollypop.lio import Lio
+from lollypop.define import Lp, ENCODING
+from lollypop.utils import format_artist_name
 
 
 class Discoverer:
@@ -156,9 +155,9 @@ class TagReader(Discoverer):
                 sortnames.append(read)
         return "; ".join(sortnames)
 
-    def get_album_artist(self, tags):
+    def get_album_artists(self, tags):
         """
-            Return album artist for tags
+            Return album artists for tags
             @param tags as Gst.TagList
             @return album artist as string or None
         """
@@ -253,7 +252,7 @@ class TagReader(Discoverer):
                     tracknumber = 0
             else:
                 tracknumber = 0
-        return tracknumber
+        return min(abs(tracknumber), GLib.MAXINT32)
 
     def get_year(self, tags):
         """
@@ -326,6 +325,27 @@ class TagReader(Discoverer):
             @parma tags as Gst.TagList
             @return lyrics as str
         """
+        def decode_lyrics(bytes):
+            try:
+                lyrics = b""
+                if bytes[0:4] == b"TXXX":
+                    if bytes[13:24] == b"L\x00y\x00r\x00i\x00c\x00s":
+                        lyrics = bytes[29:].replace(b"\x00", b"")
+                    else:
+                        return None
+                elif bytes[0:4] == b"USLT":
+                    lyrics = bytes.split(b"\xff\xfe")[2].replace(b"\x00", b"")
+                else:
+                    return None
+                for encoding in ENCODING:
+                    try:
+                        return lyrics.decode(encoding)
+                    except:
+                        pass
+            except:
+                pass
+            return None
+
         def get_mp4():
             try:
                 (exists, sample) = tags.get_string_index("lyrics", 0)
@@ -347,10 +367,9 @@ class TagReader(Discoverer):
                     (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
                     if not exists:
                         continue
-                    string = decode_all(m.data)
-                    if string.startswith("USLT"):
-                        split = string.split("\x00")
-                        return "".join(split[5:-1])
+                    string = decode_lyrics(m.data)
+                    if string is not None:
+                        return string
             except Exception as e:
                 print("TagReader::get_id3()", e)
             return ""
@@ -461,7 +480,7 @@ class TagReader(Discoverer):
         return genre_ids
 
     def add_album(self, album_name, artist_ids,
-                  uri, loved, popularity, rate, remote):
+                  uri, loved, popularity, rate, mtime):
         """
             Add album to db
             @param album name as string
@@ -471,35 +490,34 @@ class TagReader(Discoverer):
             @param loved as bool
             @param popularity as int
             @param rate as int
-            @param remote as bool
+            @param mtime as int
             @return (album id as int, new as bool)
             @commit needed
         """
-        f = Lio.File.new_for_uri(uri)
+        f = Gio.File.new_for_uri(uri)
         d = f.get_parent()
         if d is not None:
             parent_uri = d.get_uri()
         else:
             parent_uri = ""
         new = False
-        album_id = Lp().albums.get_id(album_name, artist_ids, remote)
+        album_id = Lp().albums.get_id(album_name, artist_ids)
         if album_id is None:
             new = True
             album_id = Lp().albums.add(album_name, artist_ids, parent_uri,
-                                       loved, popularity, rate)
+                                       loved, popularity, rate, mtime)
         # Now we have our album id, check if path doesn"t change
         if Lp().albums.get_uri(album_id) != parent_uri:
             Lp().albums.set_uri(album_id, parent_uri)
 
         return (album_id, new)
 
-    def update_album(self, album_id, artist_ids, genre_ids, mtime, year):
+    def update_album(self, album_id, artist_ids, genre_ids, year):
         """
             Set album artists
             @param album id as int
             @param artist ids as [int]
             @param genre ids as [int]
-            @param mtime as int
             @param year as int
             @commit needed
         """
@@ -510,13 +528,13 @@ class TagReader(Discoverer):
                                     Lp().albums.calculate_artist_ids(album_id))
         # Update album genres
         for genre_id in genre_ids:
-            Lp().albums.add_genre(album_id, genre_id, mtime)
+            Lp().albums.add_genre(album_id, genre_id)
 
         # Update year based on tracks
         year = Lp().albums.get_year_from_tracks(album_id)
         Lp().albums.set_year(album_id, year)
 
-    def update_track(self, track_id, artist_ids, genre_ids, mtime):
+    def update_track(self, track_id, artist_ids, genre_ids):
         """
             Set track artists/genres
             @param track id as int
@@ -530,4 +548,4 @@ class TagReader(Discoverer):
         for artist_id in artist_ids:
             Lp().tracks.add_artist(track_id, artist_id)
         for genre_id in genre_ids:
-            Lp().tracks.add_genre(track_id, genre_id, mtime)
+            Lp().tracks.add_genre(track_id, genre_id)
