@@ -23,7 +23,6 @@ from lollypop.pop_info import InfoPopover
 from lollypop.cache import InfoCache
 from lollypop.pop_artwork import ArtworkPopover
 from lollypop.view_artist_albums import ArtistAlbumsView
-from lollypop.lio import Lio
 
 
 class ArtistView(ArtistAlbumsView):
@@ -242,7 +241,6 @@ class ArtistView(ArtistAlbumsView):
                                                          pixbuf,
                                                          self.__scale_factor,
                                                          None)
-            del pixbuf
         else:
             surface = image.props.surface
 
@@ -295,10 +293,13 @@ class ArtistView(ArtistAlbumsView):
                 for suffix in ["lastfm", "spotify", "wikipedia"]:
                     uri = InfoCache.get_artwork(artist, suffix, size)
                     if uri is not None:
-                        f = Lio.File.new_for_path(uri)
+                        f = Gio.File.new_for_path(uri)
                         (status, data, tag) = f.load_contents(None)
-                        stream = Gio.MemoryInputStream.new_from_data(data,
-                                                                     None)
+                        if not status:
+                            continue
+                        bytes = GLib.Bytes(data)
+                        stream = Gio.MemoryInputStream.new_from_bytes(bytes)
+                        bytes.unref()
                         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                                                                        stream,
                                                                        size,
@@ -308,9 +309,7 @@ class ArtistView(ArtistAlbumsView):
                         stream.close()
                         surface = Gdk.cairo_surface_create_from_pixbuf(
                                             pixbuf, self.__scale_factor, None)
-                        del pixbuf
                         self.__artwork.set_from_surface(surface)
-                        del surface
                         artwork_height = ArtSize.ARTIST_SMALL * 2
                         self.__artwork.get_style_context().remove_class(
                                                                 "artwork-icon")
