@@ -112,8 +112,9 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
             Return preferred width
             @return (int, int)
         """
-        # Padding: 3px, border: 1px + spacing
-        width = ArtSize.BIG + 16
+        if self._widget is None:
+            return (0, 0)
+        width = Gtk.FlowBoxChild.do_get_preferred_width(self)[0]
         return (width, width)
 
     def set_name(self, name):
@@ -135,7 +136,6 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
                     ArtSize.BIG,
                     self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
-        del surface
 
     def update_cover(self):
         """
@@ -148,7 +148,6 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
                     ArtSize.BIG,
                     self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
-        del surface
 
     def update_state(self):
         """
